# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *
from ._inputs import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_azure.aadb2c as __aadb2c
    aadb2c = __aadb2c
    import pulumi_azure.advisor as __advisor
    advisor = __advisor
    import pulumi_azure.analysisservices as __analysisservices
    analysisservices = __analysisservices
    import pulumi_azure.apimanagement as __apimanagement
    apimanagement = __apimanagement
    import pulumi_azure.appconfiguration as __appconfiguration
    appconfiguration = __appconfiguration
    import pulumi_azure.appinsights as __appinsights
    appinsights = __appinsights
    import pulumi_azure.appplatform as __appplatform
    appplatform = __appplatform
    import pulumi_azure.appservice as __appservice
    appservice = __appservice
    import pulumi_azure.arc as __arc
    arc = __arc
    import pulumi_azure.arckubernetes as __arckubernetes
    arckubernetes = __arckubernetes
    import pulumi_azure.arcmachine as __arcmachine
    arcmachine = __arcmachine
    import pulumi_azure.armmsi as __armmsi
    armmsi = __armmsi
    import pulumi_azure.attestation as __attestation
    attestation = __attestation
    import pulumi_azure.authorization as __authorization
    authorization = __authorization
    import pulumi_azure.automanage as __automanage
    automanage = __automanage
    import pulumi_azure.automation as __automation
    automation = __automation
    import pulumi_azure.avs as __avs
    avs = __avs
    import pulumi_azure.backup as __backup
    backup = __backup
    import pulumi_azure.batch as __batch
    batch = __batch
    import pulumi_azure.billing as __billing
    billing = __billing
    import pulumi_azure.blueprint as __blueprint
    blueprint = __blueprint
    import pulumi_azure.bot as __bot
    bot = __bot
    import pulumi_azure.cdn as __cdn
    cdn = __cdn
    import pulumi_azure.chaosstudio as __chaosstudio
    chaosstudio = __chaosstudio
    import pulumi_azure.cognitive as __cognitive
    cognitive = __cognitive
    import pulumi_azure.communication as __communication
    communication = __communication
    import pulumi_azure.compute as __compute
    compute = __compute
    import pulumi_azure.confidentialledger as __confidentialledger
    confidentialledger = __confidentialledger
    import pulumi_azure.config as __config
    config = __config
    import pulumi_azure.connections as __connections
    connections = __connections
    import pulumi_azure.consumption as __consumption
    consumption = __consumption
    import pulumi_azure.containerapp as __containerapp
    containerapp = __containerapp
    import pulumi_azure.containerservice as __containerservice
    containerservice = __containerservice
    import pulumi_azure.core as __core
    core = __core
    import pulumi_azure.cosmosdb as __cosmosdb
    cosmosdb = __cosmosdb
    import pulumi_azure.costmanagement as __costmanagement
    costmanagement = __costmanagement
    import pulumi_azure.customip as __customip
    customip = __customip
    import pulumi_azure.dashboard as __dashboard
    dashboard = __dashboard
    import pulumi_azure.databasemigration as __databasemigration
    databasemigration = __databasemigration
    import pulumi_azure.databoxedge as __databoxedge
    databoxedge = __databoxedge
    import pulumi_azure.databricks as __databricks
    databricks = __databricks
    import pulumi_azure.datadog as __datadog
    datadog = __datadog
    import pulumi_azure.datafactory as __datafactory
    datafactory = __datafactory
    import pulumi_azure.dataprotection as __dataprotection
    dataprotection = __dataprotection
    import pulumi_azure.datashare as __datashare
    datashare = __datashare
    import pulumi_azure.desktopvirtualization as __desktopvirtualization
    desktopvirtualization = __desktopvirtualization
    import pulumi_azure.devcenter as __devcenter
    devcenter = __devcenter
    import pulumi_azure.devtest as __devtest
    devtest = __devtest
    import pulumi_azure.digitaltwins as __digitaltwins
    digitaltwins = __digitaltwins
    import pulumi_azure.dns as __dns
    dns = __dns
    import pulumi_azure.domainservices as __domainservices
    domainservices = __domainservices
    import pulumi_azure.dynatrace as __dynatrace
    dynatrace = __dynatrace
    import pulumi_azure.elasticcloud as __elasticcloud
    elasticcloud = __elasticcloud
    import pulumi_azure.elasticsan as __elasticsan
    elasticsan = __elasticsan
    import pulumi_azure.eventgrid as __eventgrid
    eventgrid = __eventgrid
    import pulumi_azure.eventhub as __eventhub
    eventhub = __eventhub
    import pulumi_azure.expressroute as __expressroute
    expressroute = __expressroute
    import pulumi_azure.extendedlocation as __extendedlocation
    extendedlocation = __extendedlocation
    import pulumi_azure.fabric as __fabric
    fabric = __fabric
    import pulumi_azure.fluidrelay as __fluidrelay
    fluidrelay = __fluidrelay
    import pulumi_azure.frontdoor as __frontdoor
    frontdoor = __frontdoor
    import pulumi_azure.graph as __graph
    graph = __graph
    import pulumi_azure.hdinsight as __hdinsight
    hdinsight = __hdinsight
    import pulumi_azure.healthcare as __healthcare
    healthcare = __healthcare
    import pulumi_azure.hpc as __hpc
    hpc = __hpc
    import pulumi_azure.hsm as __hsm
    hsm = __hsm
    import pulumi_azure.iot as __iot
    iot = __iot
    import pulumi_azure.iotcentral as __iotcentral
    iotcentral = __iotcentral
    import pulumi_azure.keyvault as __keyvault
    keyvault = __keyvault
    import pulumi_azure.kusto as __kusto
    kusto = __kusto
    import pulumi_azure.lb as __lb
    lb = __lb
    import pulumi_azure.lighthouse as __lighthouse
    lighthouse = __lighthouse
    import pulumi_azure.loadtest as __loadtest
    loadtest = __loadtest
    import pulumi_azure.loganalytics as __loganalytics
    loganalytics = __loganalytics
    import pulumi_azure.logicapps as __logicapps
    logicapps = __logicapps
    import pulumi_azure.machinelearning as __machinelearning
    machinelearning = __machinelearning
    import pulumi_azure.maintenance as __maintenance
    maintenance = __maintenance
    import pulumi_azure.managedapplication as __managedapplication
    managedapplication = __managedapplication
    import pulumi_azure.managedlustre as __managedlustre
    managedlustre = __managedlustre
    import pulumi_azure.management as __management
    management = __management
    import pulumi_azure.managementgroups as __managementgroups
    managementgroups = __managementgroups
    import pulumi_azure.managementresource as __managementresource
    managementresource = __managementresource
    import pulumi_azure.maps as __maps
    maps = __maps
    import pulumi_azure.marketplace as __marketplace
    marketplace = __marketplace
    import pulumi_azure.mixedreality as __mixedreality
    mixedreality = __mixedreality
    import pulumi_azure.mobile as __mobile
    mobile = __mobile
    import pulumi_azure.monitoring as __monitoring
    monitoring = __monitoring
    import pulumi_azure.msi as __msi
    msi = __msi
    import pulumi_azure.mssql as __mssql
    mssql = __mssql
    import pulumi_azure.mysql as __mysql
    mysql = __mysql
    import pulumi_azure.netapp as __netapp
    netapp = __netapp
    import pulumi_azure.network as __network
    network = __network
    import pulumi_azure.networkfunction as __networkfunction
    networkfunction = __networkfunction
    import pulumi_azure.newrelic as __newrelic
    newrelic = __newrelic
    import pulumi_azure.nginx as __nginx
    nginx = __nginx
    import pulumi_azure.notificationhub as __notificationhub
    notificationhub = __notificationhub
    import pulumi_azure.operationalinsights as __operationalinsights
    operationalinsights = __operationalinsights
    import pulumi_azure.oracle as __oracle
    oracle = __oracle
    import pulumi_azure.orbital as __orbital
    orbital = __orbital
    import pulumi_azure.paloalto as __paloalto
    paloalto = __paloalto
    import pulumi_azure.pim as __pim
    pim = __pim
    import pulumi_azure.policy as __policy
    policy = __policy
    import pulumi_azure.portal as __portal
    portal = __portal
    import pulumi_azure.postgresql as __postgresql
    postgresql = __postgresql
    import pulumi_azure.powerbi as __powerbi
    powerbi = __powerbi
    import pulumi_azure.privatedns as __privatedns
    privatedns = __privatedns
    import pulumi_azure.privatelink as __privatelink
    privatelink = __privatelink
    import pulumi_azure.proximity as __proximity
    proximity = __proximity
    import pulumi_azure.purview as __purview
    purview = __purview
    import pulumi_azure.recoveryservices as __recoveryservices
    recoveryservices = __recoveryservices
    import pulumi_azure.redhatopenshift as __redhatopenshift
    redhatopenshift = __redhatopenshift
    import pulumi_azure.redis as __redis
    redis = __redis
    import pulumi_azure.relay as __relay
    relay = __relay
    import pulumi_azure.role as __role
    role = __role
    import pulumi_azure.search as __search
    search = __search
    import pulumi_azure.securitycenter as __securitycenter
    securitycenter = __securitycenter
    import pulumi_azure.sentinel as __sentinel
    sentinel = __sentinel
    import pulumi_azure.servicebus as __servicebus
    servicebus = __servicebus
    import pulumi_azure.servicefabric as __servicefabric
    servicefabric = __servicefabric
    import pulumi_azure.signalr as __signalr
    signalr = __signalr
    import pulumi_azure.siterecovery as __siterecovery
    siterecovery = __siterecovery
    import pulumi_azure.stack as __stack
    stack = __stack
    import pulumi_azure.storage as __storage
    storage = __storage
    import pulumi_azure.streamanalytics as __streamanalytics
    streamanalytics = __streamanalytics
    import pulumi_azure.synapse as __synapse
    synapse = __synapse
    import pulumi_azure.systemcenter as __systemcenter
    systemcenter = __systemcenter
    import pulumi_azure.trafficmanager as __trafficmanager
    trafficmanager = __trafficmanager
    import pulumi_azure.trustedsigning as __trustedsigning
    trustedsigning = __trustedsigning
    import pulumi_azure.videoindexer as __videoindexer
    videoindexer = __videoindexer
    import pulumi_azure.voice as __voice
    voice = __voice
    import pulumi_azure.waf as __waf
    waf = __waf
    import pulumi_azure.webpubsub as __webpubsub
    webpubsub = __webpubsub
    import pulumi_azure.workloadssap as __workloadssap
    workloadssap = __workloadssap
else:
    aadb2c = _utilities.lazy_import('pulumi_azure.aadb2c')
    advisor = _utilities.lazy_import('pulumi_azure.advisor')
    analysisservices = _utilities.lazy_import('pulumi_azure.analysisservices')
    apimanagement = _utilities.lazy_import('pulumi_azure.apimanagement')
    appconfiguration = _utilities.lazy_import('pulumi_azure.appconfiguration')
    appinsights = _utilities.lazy_import('pulumi_azure.appinsights')
    appplatform = _utilities.lazy_import('pulumi_azure.appplatform')
    appservice = _utilities.lazy_import('pulumi_azure.appservice')
    arc = _utilities.lazy_import('pulumi_azure.arc')
    arckubernetes = _utilities.lazy_import('pulumi_azure.arckubernetes')
    arcmachine = _utilities.lazy_import('pulumi_azure.arcmachine')
    armmsi = _utilities.lazy_import('pulumi_azure.armmsi')
    attestation = _utilities.lazy_import('pulumi_azure.attestation')
    authorization = _utilities.lazy_import('pulumi_azure.authorization')
    automanage = _utilities.lazy_import('pulumi_azure.automanage')
    automation = _utilities.lazy_import('pulumi_azure.automation')
    avs = _utilities.lazy_import('pulumi_azure.avs')
    backup = _utilities.lazy_import('pulumi_azure.backup')
    batch = _utilities.lazy_import('pulumi_azure.batch')
    billing = _utilities.lazy_import('pulumi_azure.billing')
    blueprint = _utilities.lazy_import('pulumi_azure.blueprint')
    bot = _utilities.lazy_import('pulumi_azure.bot')
    cdn = _utilities.lazy_import('pulumi_azure.cdn')
    chaosstudio = _utilities.lazy_import('pulumi_azure.chaosstudio')
    cognitive = _utilities.lazy_import('pulumi_azure.cognitive')
    communication = _utilities.lazy_import('pulumi_azure.communication')
    compute = _utilities.lazy_import('pulumi_azure.compute')
    confidentialledger = _utilities.lazy_import('pulumi_azure.confidentialledger')
    config = _utilities.lazy_import('pulumi_azure.config')
    connections = _utilities.lazy_import('pulumi_azure.connections')
    consumption = _utilities.lazy_import('pulumi_azure.consumption')
    containerapp = _utilities.lazy_import('pulumi_azure.containerapp')
    containerservice = _utilities.lazy_import('pulumi_azure.containerservice')
    core = _utilities.lazy_import('pulumi_azure.core')
    cosmosdb = _utilities.lazy_import('pulumi_azure.cosmosdb')
    costmanagement = _utilities.lazy_import('pulumi_azure.costmanagement')
    customip = _utilities.lazy_import('pulumi_azure.customip')
    dashboard = _utilities.lazy_import('pulumi_azure.dashboard')
    databasemigration = _utilities.lazy_import('pulumi_azure.databasemigration')
    databoxedge = _utilities.lazy_import('pulumi_azure.databoxedge')
    databricks = _utilities.lazy_import('pulumi_azure.databricks')
    datadog = _utilities.lazy_import('pulumi_azure.datadog')
    datafactory = _utilities.lazy_import('pulumi_azure.datafactory')
    dataprotection = _utilities.lazy_import('pulumi_azure.dataprotection')
    datashare = _utilities.lazy_import('pulumi_azure.datashare')
    desktopvirtualization = _utilities.lazy_import('pulumi_azure.desktopvirtualization')
    devcenter = _utilities.lazy_import('pulumi_azure.devcenter')
    devtest = _utilities.lazy_import('pulumi_azure.devtest')
    digitaltwins = _utilities.lazy_import('pulumi_azure.digitaltwins')
    dns = _utilities.lazy_import('pulumi_azure.dns')
    domainservices = _utilities.lazy_import('pulumi_azure.domainservices')
    dynatrace = _utilities.lazy_import('pulumi_azure.dynatrace')
    elasticcloud = _utilities.lazy_import('pulumi_azure.elasticcloud')
    elasticsan = _utilities.lazy_import('pulumi_azure.elasticsan')
    eventgrid = _utilities.lazy_import('pulumi_azure.eventgrid')
    eventhub = _utilities.lazy_import('pulumi_azure.eventhub')
    expressroute = _utilities.lazy_import('pulumi_azure.expressroute')
    extendedlocation = _utilities.lazy_import('pulumi_azure.extendedlocation')
    fabric = _utilities.lazy_import('pulumi_azure.fabric')
    fluidrelay = _utilities.lazy_import('pulumi_azure.fluidrelay')
    frontdoor = _utilities.lazy_import('pulumi_azure.frontdoor')
    graph = _utilities.lazy_import('pulumi_azure.graph')
    hdinsight = _utilities.lazy_import('pulumi_azure.hdinsight')
    healthcare = _utilities.lazy_import('pulumi_azure.healthcare')
    hpc = _utilities.lazy_import('pulumi_azure.hpc')
    hsm = _utilities.lazy_import('pulumi_azure.hsm')
    iot = _utilities.lazy_import('pulumi_azure.iot')
    iotcentral = _utilities.lazy_import('pulumi_azure.iotcentral')
    keyvault = _utilities.lazy_import('pulumi_azure.keyvault')
    kusto = _utilities.lazy_import('pulumi_azure.kusto')
    lb = _utilities.lazy_import('pulumi_azure.lb')
    lighthouse = _utilities.lazy_import('pulumi_azure.lighthouse')
    loadtest = _utilities.lazy_import('pulumi_azure.loadtest')
    loganalytics = _utilities.lazy_import('pulumi_azure.loganalytics')
    logicapps = _utilities.lazy_import('pulumi_azure.logicapps')
    machinelearning = _utilities.lazy_import('pulumi_azure.machinelearning')
    maintenance = _utilities.lazy_import('pulumi_azure.maintenance')
    managedapplication = _utilities.lazy_import('pulumi_azure.managedapplication')
    managedlustre = _utilities.lazy_import('pulumi_azure.managedlustre')
    management = _utilities.lazy_import('pulumi_azure.management')
    managementgroups = _utilities.lazy_import('pulumi_azure.managementgroups')
    managementresource = _utilities.lazy_import('pulumi_azure.managementresource')
    maps = _utilities.lazy_import('pulumi_azure.maps')
    marketplace = _utilities.lazy_import('pulumi_azure.marketplace')
    mixedreality = _utilities.lazy_import('pulumi_azure.mixedreality')
    mobile = _utilities.lazy_import('pulumi_azure.mobile')
    monitoring = _utilities.lazy_import('pulumi_azure.monitoring')
    msi = _utilities.lazy_import('pulumi_azure.msi')
    mssql = _utilities.lazy_import('pulumi_azure.mssql')
    mysql = _utilities.lazy_import('pulumi_azure.mysql')
    netapp = _utilities.lazy_import('pulumi_azure.netapp')
    network = _utilities.lazy_import('pulumi_azure.network')
    networkfunction = _utilities.lazy_import('pulumi_azure.networkfunction')
    newrelic = _utilities.lazy_import('pulumi_azure.newrelic')
    nginx = _utilities.lazy_import('pulumi_azure.nginx')
    notificationhub = _utilities.lazy_import('pulumi_azure.notificationhub')
    operationalinsights = _utilities.lazy_import('pulumi_azure.operationalinsights')
    oracle = _utilities.lazy_import('pulumi_azure.oracle')
    orbital = _utilities.lazy_import('pulumi_azure.orbital')
    paloalto = _utilities.lazy_import('pulumi_azure.paloalto')
    pim = _utilities.lazy_import('pulumi_azure.pim')
    policy = _utilities.lazy_import('pulumi_azure.policy')
    portal = _utilities.lazy_import('pulumi_azure.portal')
    postgresql = _utilities.lazy_import('pulumi_azure.postgresql')
    powerbi = _utilities.lazy_import('pulumi_azure.powerbi')
    privatedns = _utilities.lazy_import('pulumi_azure.privatedns')
    privatelink = _utilities.lazy_import('pulumi_azure.privatelink')
    proximity = _utilities.lazy_import('pulumi_azure.proximity')
    purview = _utilities.lazy_import('pulumi_azure.purview')
    recoveryservices = _utilities.lazy_import('pulumi_azure.recoveryservices')
    redhatopenshift = _utilities.lazy_import('pulumi_azure.redhatopenshift')
    redis = _utilities.lazy_import('pulumi_azure.redis')
    relay = _utilities.lazy_import('pulumi_azure.relay')
    role = _utilities.lazy_import('pulumi_azure.role')
    search = _utilities.lazy_import('pulumi_azure.search')
    securitycenter = _utilities.lazy_import('pulumi_azure.securitycenter')
    sentinel = _utilities.lazy_import('pulumi_azure.sentinel')
    servicebus = _utilities.lazy_import('pulumi_azure.servicebus')
    servicefabric = _utilities.lazy_import('pulumi_azure.servicefabric')
    signalr = _utilities.lazy_import('pulumi_azure.signalr')
    siterecovery = _utilities.lazy_import('pulumi_azure.siterecovery')
    stack = _utilities.lazy_import('pulumi_azure.stack')
    storage = _utilities.lazy_import('pulumi_azure.storage')
    streamanalytics = _utilities.lazy_import('pulumi_azure.streamanalytics')
    synapse = _utilities.lazy_import('pulumi_azure.synapse')
    systemcenter = _utilities.lazy_import('pulumi_azure.systemcenter')
    trafficmanager = _utilities.lazy_import('pulumi_azure.trafficmanager')
    trustedsigning = _utilities.lazy_import('pulumi_azure.trustedsigning')
    videoindexer = _utilities.lazy_import('pulumi_azure.videoindexer')
    voice = _utilities.lazy_import('pulumi_azure.voice')
    waf = _utilities.lazy_import('pulumi_azure.waf')
    webpubsub = _utilities.lazy_import('pulumi_azure.webpubsub')
    workloadssap = _utilities.lazy_import('pulumi_azure.workloadssap')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "azure",
  "mod": "aadb2c/directory",
  "fqn": "pulumi_azure.aadb2c",
  "classes": {
   "azure:aadb2c/directory:Directory": "Directory"
  }
 },
 {
  "pkg": "azure",
  "mod": "advisor/suppression",
  "fqn": "pulumi_azure.advisor",
  "classes": {
   "azure:advisor/suppression:Suppression": "Suppression"
  }
 },
 {
  "pkg": "azure",
  "mod": "analysisservices/server",
  "fqn": "pulumi_azure.analysisservices",
  "classes": {
   "azure:analysisservices/server:Server": "Server"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/api",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/api:Api": "Api"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiDiagnostic",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiDiagnostic:ApiDiagnostic": "ApiDiagnostic"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiOperation",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiOperation:ApiOperation": "ApiOperation"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiOperationPolicy",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiOperationPolicy:ApiOperationPolicy": "ApiOperationPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiOperationTag",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiOperationTag:ApiOperationTag": "ApiOperationTag"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiPolicy",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiPolicy:ApiPolicy": "ApiPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiRelease",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiRelease:ApiRelease": "ApiRelease"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiSchema",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiSchema:ApiSchema": "ApiSchema"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiTag",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiTag:ApiTag": "ApiTag"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiTagDescription",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiTagDescription:ApiTagDescription": "ApiTagDescription"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/apiVersionSet",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/apiVersionSet:ApiVersionSet": "ApiVersionSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/authorizationServer",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/authorizationServer:AuthorizationServer": "AuthorizationServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/backend",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/backend:Backend": "Backend"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/certificate",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/customDomain",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/customDomain:CustomDomain": "CustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/diagnostic",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/diagnostic:Diagnostic": "Diagnostic"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/emailTemplate",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/emailTemplate:EmailTemplate": "EmailTemplate"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/gateway",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/gatewayApi",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/gatewayApi:GatewayApi": "GatewayApi"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/gatewayCertificateAuthority",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/gatewayCertificateAuthority:GatewayCertificateAuthority": "GatewayCertificateAuthority"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/gatewayHostNameConfiguration",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/gatewayHostNameConfiguration:GatewayHostNameConfiguration": "GatewayHostNameConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/globalSchema",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/globalSchema:GlobalSchema": "GlobalSchema"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/group",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/group:Group": "Group"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/groupUser",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/groupUser:GroupUser": "GroupUser"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderAad",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderAad:IdentityProviderAad": "IdentityProviderAad"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderAadb2c",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderAadb2c:IdentityProviderAadb2c": "IdentityProviderAadb2c"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderFacebook",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderFacebook:IdentityProviderFacebook": "IdentityProviderFacebook"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderGoogle",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderGoogle:IdentityProviderGoogle": "IdentityProviderGoogle"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderMicrosoft",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderMicrosoft:IdentityProviderMicrosoft": "IdentityProviderMicrosoft"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/identityProviderTwitter",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/identityProviderTwitter:IdentityProviderTwitter": "IdentityProviderTwitter"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/logger",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/logger:Logger": "Logger"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/namedValue",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/namedValue:NamedValue": "NamedValue"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/notificationRecipientEmail",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/notificationRecipientEmail:NotificationRecipientEmail": "NotificationRecipientEmail"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/notificationRecipientUser",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/notificationRecipientUser:NotificationRecipientUser": "NotificationRecipientUser"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/openIdConnectProvider",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/openIdConnectProvider:OpenIdConnectProvider": "OpenIdConnectProvider"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/policy",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/policyFragment",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/policyFragment:PolicyFragment": "PolicyFragment"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/product",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/product:Product": "Product"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/productApi",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/productApi:ProductApi": "ProductApi"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/productGroup",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/productGroup:ProductGroup": "ProductGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/productPolicy",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/productPolicy:ProductPolicy": "ProductPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/productTag",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/productTag:ProductTag": "ProductTag"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/redisCache",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/redisCache:RedisCache": "RedisCache"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/service",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/subscription",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/tag",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "azure",
  "mod": "apimanagement/user",
  "fqn": "pulumi_azure.apimanagement",
  "classes": {
   "azure:apimanagement/user:User": "User"
  }
 },
 {
  "pkg": "azure",
  "mod": "appconfiguration/configurationFeature",
  "fqn": "pulumi_azure.appconfiguration",
  "classes": {
   "azure:appconfiguration/configurationFeature:ConfigurationFeature": "ConfigurationFeature"
  }
 },
 {
  "pkg": "azure",
  "mod": "appconfiguration/configurationKey",
  "fqn": "pulumi_azure.appconfiguration",
  "classes": {
   "azure:appconfiguration/configurationKey:ConfigurationKey": "ConfigurationKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "appconfiguration/configurationStore",
  "fqn": "pulumi_azure.appconfiguration",
  "classes": {
   "azure:appconfiguration/configurationStore:ConfigurationStore": "ConfigurationStore"
  }
 },
 {
  "pkg": "azure",
  "mod": "appconfiguration/licationLoadBalancer",
  "fqn": "pulumi_azure.appconfiguration",
  "classes": {
   "azure:appconfiguration/licationLoadBalancer:LicationLoadBalancer": "LicationLoadBalancer"
  }
 },
 {
  "pkg": "azure",
  "mod": "appconfiguration/licationLoadBalancerFrontend",
  "fqn": "pulumi_azure.appconfiguration",
  "classes": {
   "azure:appconfiguration/licationLoadBalancerFrontend:LicationLoadBalancerFrontend": "LicationLoadBalancerFrontend"
  }
 },
 {
  "pkg": "azure",
  "mod": "appconfiguration/licationLoadBalancerSubnetAssociation",
  "fqn": "pulumi_azure.appconfiguration",
  "classes": {
   "azure:appconfiguration/licationLoadBalancerSubnetAssociation:LicationLoadBalancerSubnetAssociation": "LicationLoadBalancerSubnetAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/analyticsItem",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/analyticsItem:AnalyticsItem": "AnalyticsItem"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/apiKey",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/insights",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/insights:Insights": "Insights"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/smartDetectionRule",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/smartDetectionRule:SmartDetectionRule": "SmartDetectionRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/standardWebTest",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/standardWebTest:StandardWebTest": "StandardWebTest"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/webTest",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/webTest:WebTest": "WebTest"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/workbook",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/workbook:Workbook": "Workbook"
  }
 },
 {
  "pkg": "azure",
  "mod": "appinsights/workbookTemplate",
  "fqn": "pulumi_azure.appinsights",
  "classes": {
   "azure:appinsights/workbookTemplate:WorkbookTemplate": "WorkbookTemplate"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudAccelerator",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudAccelerator:SpringCloudAccelerator": "SpringCloudAccelerator"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudActiveDeployment",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudActiveDeployment:SpringCloudActiveDeployment": "SpringCloudActiveDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudApiPortal",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudApiPortal:SpringCloudApiPortal": "SpringCloudApiPortal"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudApiPortalCustomDomain",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudApiPortalCustomDomain:SpringCloudApiPortalCustomDomain": "SpringCloudApiPortalCustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudApp",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudApp:SpringCloudApp": "SpringCloudApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudAppCosmosDBAssociation",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudAppCosmosDBAssociation:SpringCloudAppCosmosDBAssociation": "SpringCloudAppCosmosDBAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudAppDynamicsApplicationPerformanceMonitoring",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudAppDynamicsApplicationPerformanceMonitoring:SpringCloudAppDynamicsApplicationPerformanceMonitoring": "SpringCloudAppDynamicsApplicationPerformanceMonitoring"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudAppMysqlAssociation",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudAppMysqlAssociation:SpringCloudAppMysqlAssociation": "SpringCloudAppMysqlAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudAppRedisAssociation",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudAppRedisAssociation:SpringCloudAppRedisAssociation": "SpringCloudAppRedisAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudApplicationInsightsApplicationPerformanceMonitoring",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudApplicationInsightsApplicationPerformanceMonitoring:SpringCloudApplicationInsightsApplicationPerformanceMonitoring": "SpringCloudApplicationInsightsApplicationPerformanceMonitoring"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudApplicationLiveView",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudApplicationLiveView:SpringCloudApplicationLiveView": "SpringCloudApplicationLiveView"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudBuildDeployment",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudBuildDeployment:SpringCloudBuildDeployment": "SpringCloudBuildDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudBuildPackBinding",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudBuildPackBinding:SpringCloudBuildPackBinding": "SpringCloudBuildPackBinding"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudBuilder",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudBuilder:SpringCloudBuilder": "SpringCloudBuilder"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudCertificate",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudCertificate:SpringCloudCertificate": "SpringCloudCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudConfigurationService",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudConfigurationService:SpringCloudConfigurationService": "SpringCloudConfigurationService"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudConnection",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudConnection:SpringCloudConnection": "SpringCloudConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudContainerDeployment",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudContainerDeployment:SpringCloudContainerDeployment": "SpringCloudContainerDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudCustomDomain",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudCustomDomain:SpringCloudCustomDomain": "SpringCloudCustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudCustomizedAccelerator",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudCustomizedAccelerator:SpringCloudCustomizedAccelerator": "SpringCloudCustomizedAccelerator"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudDevToolPortal",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudDevToolPortal:SpringCloudDevToolPortal": "SpringCloudDevToolPortal"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudDynatraceApplicationPerformanceMonitoring",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudDynatraceApplicationPerformanceMonitoring:SpringCloudDynatraceApplicationPerformanceMonitoring": "SpringCloudDynatraceApplicationPerformanceMonitoring"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudElasticApplicationPerformanceMonitoring",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudElasticApplicationPerformanceMonitoring:SpringCloudElasticApplicationPerformanceMonitoring": "SpringCloudElasticApplicationPerformanceMonitoring"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudGateway",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudGateway:SpringCloudGateway": "SpringCloudGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudGatewayCustomDomain",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudGatewayCustomDomain:SpringCloudGatewayCustomDomain": "SpringCloudGatewayCustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudGatewayRouteConfig",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudGatewayRouteConfig:SpringCloudGatewayRouteConfig": "SpringCloudGatewayRouteConfig"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudJavaDeployment",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudJavaDeployment:SpringCloudJavaDeployment": "SpringCloudJavaDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudNewRelicApplicationPerformanceMonitoring",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudNewRelicApplicationPerformanceMonitoring:SpringCloudNewRelicApplicationPerformanceMonitoring": "SpringCloudNewRelicApplicationPerformanceMonitoring"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudService",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudService:SpringCloudService": "SpringCloudService"
  }
 },
 {
  "pkg": "azure",
  "mod": "appplatform/springCloudStorage",
  "fqn": "pulumi_azure.appplatform",
  "classes": {
   "azure:appplatform/springCloudStorage:SpringCloudStorage": "SpringCloudStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/activeSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/activeSlot:ActiveSlot": "ActiveSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/appConnection",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/appConnection:AppConnection": "AppConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/appService",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/appService:AppService": "AppService"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/certificate",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/certificateBinding",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/certificateBinding:CertificateBinding": "CertificateBinding"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/certificateOrder",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/certificateOrder:CertificateOrder": "CertificateOrder"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/connection",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/customHostnameBinding",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/customHostnameBinding:CustomHostnameBinding": "CustomHostnameBinding"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/environmentV3",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/environmentV3:EnvironmentV3": "EnvironmentV3"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/functionApp",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/functionApp:FunctionApp": "FunctionApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/functionAppActiveSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/functionAppActiveSlot:FunctionAppActiveSlot": "FunctionAppActiveSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/functionAppFunction",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/functionAppFunction:FunctionAppFunction": "FunctionAppFunction"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/functionAppHybridConnection",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/functionAppHybridConnection:FunctionAppHybridConnection": "FunctionAppHybridConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/functionAppSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/functionAppSlot:FunctionAppSlot": "FunctionAppSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/hybridConnection",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/hybridConnection:HybridConnection": "HybridConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/linuxFunctionApp",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/linuxFunctionApp:LinuxFunctionApp": "LinuxFunctionApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/linuxFunctionAppSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/linuxFunctionAppSlot:LinuxFunctionAppSlot": "LinuxFunctionAppSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/linuxWebApp",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/linuxWebApp:LinuxWebApp": "LinuxWebApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/linuxWebAppSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/linuxWebAppSlot:LinuxWebAppSlot": "LinuxWebAppSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/managedCertificate",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/managedCertificate:ManagedCertificate": "ManagedCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/plan",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/plan:Plan": "Plan"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/publicCertificate",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/publicCertificate:PublicCertificate": "PublicCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/servicePlan",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/servicePlan:ServicePlan": "ServicePlan"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/slot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/slot:Slot": "Slot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/slotCustomHostnameBinding",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/slotCustomHostnameBinding:SlotCustomHostnameBinding": "SlotCustomHostnameBinding"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/slotVirtualNetworkSwiftConnection",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/slotVirtualNetworkSwiftConnection:SlotVirtualNetworkSwiftConnection": "SlotVirtualNetworkSwiftConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/sourceCodeToken",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/sourceCodeToken:SourceCodeToken": "SourceCodeToken"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/sourceControl",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/sourceControl:SourceControl": "SourceControl"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/sourceControlSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/sourceControlSlot:SourceControlSlot": "SourceControlSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/sourceControlToken",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/sourceControlToken:SourceControlToken": "SourceControlToken"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/staticSite",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/staticSite:StaticSite": "StaticSite"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/staticSiteCustomDomain",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/staticSiteCustomDomain:StaticSiteCustomDomain": "StaticSiteCustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/staticWebApp",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/staticWebApp:StaticWebApp": "StaticWebApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/staticWebAppCustomDomain",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/staticWebAppCustomDomain:StaticWebAppCustomDomain": "StaticWebAppCustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/staticWebAppFunctionAppRegistration",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/staticWebAppFunctionAppRegistration:StaticWebAppFunctionAppRegistration": "StaticWebAppFunctionAppRegistration"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/virtualNetworkSwiftConnection",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/virtualNetworkSwiftConnection:VirtualNetworkSwiftConnection": "VirtualNetworkSwiftConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/webAppActiveSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/webAppActiveSlot:WebAppActiveSlot": "WebAppActiveSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/webAppHybridConnection",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/webAppHybridConnection:WebAppHybridConnection": "WebAppHybridConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/windowsFunctionApp",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/windowsFunctionApp:WindowsFunctionApp": "WindowsFunctionApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/windowsFunctionAppSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/windowsFunctionAppSlot:WindowsFunctionAppSlot": "WindowsFunctionAppSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/windowsWebApp",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/windowsWebApp:WindowsWebApp": "WindowsWebApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "appservice/windowsWebAppSlot",
  "fqn": "pulumi_azure.appservice",
  "classes": {
   "azure:appservice/windowsWebAppSlot:WindowsWebAppSlot": "WindowsWebAppSlot"
  }
 },
 {
  "pkg": "azure",
  "mod": "arc/privateLinkScope",
  "fqn": "pulumi_azure.arc",
  "classes": {
   "azure:arc/privateLinkScope:PrivateLinkScope": "PrivateLinkScope"
  }
 },
 {
  "pkg": "azure",
  "mod": "arc/resourceBridgeAppliance",
  "fqn": "pulumi_azure.arc",
  "classes": {
   "azure:arc/resourceBridgeAppliance:ResourceBridgeAppliance": "ResourceBridgeAppliance"
  }
 },
 {
  "pkg": "azure",
  "mod": "arckubernetes/cluster",
  "fqn": "pulumi_azure.arckubernetes",
  "classes": {
   "azure:arckubernetes/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "arckubernetes/clusterExtension",
  "fqn": "pulumi_azure.arckubernetes",
  "classes": {
   "azure:arckubernetes/clusterExtension:ClusterExtension": "ClusterExtension"
  }
 },
 {
  "pkg": "azure",
  "mod": "arckubernetes/fluxConfiguration",
  "fqn": "pulumi_azure.arckubernetes",
  "classes": {
   "azure:arckubernetes/fluxConfiguration:FluxConfiguration": "FluxConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "arckubernetes/provisionedCluster",
  "fqn": "pulumi_azure.arckubernetes",
  "classes": {
   "azure:arckubernetes/provisionedCluster:ProvisionedCluster": "ProvisionedCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "arcmachine/arcMachine",
  "fqn": "pulumi_azure.arcmachine",
  "classes": {
   "azure:arcmachine/arcMachine:ArcMachine": "ArcMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "arcmachine/automanageConfigurationAssignment",
  "fqn": "pulumi_azure.arcmachine",
  "classes": {
   "azure:arcmachine/automanageConfigurationAssignment:AutomanageConfigurationAssignment": "AutomanageConfigurationAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "arcmachine/extension",
  "fqn": "pulumi_azure.arcmachine",
  "classes": {
   "azure:arcmachine/extension:Extension": "Extension"
  }
 },
 {
  "pkg": "azure",
  "mod": "armmsi/federatedIdentityCredential",
  "fqn": "pulumi_azure.armmsi",
  "classes": {
   "azure:armmsi/federatedIdentityCredential:FederatedIdentityCredential": "FederatedIdentityCredential"
  }
 },
 {
  "pkg": "azure",
  "mod": "attestation/provider",
  "fqn": "pulumi_azure.attestation",
  "classes": {
   "azure:attestation/provider:Provider": "Provider"
  }
 },
 {
  "pkg": "azure",
  "mod": "authorization/assignment",
  "fqn": "pulumi_azure.authorization",
  "classes": {
   "azure:authorization/assignment:Assignment": "Assignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "authorization/roleDefinition",
  "fqn": "pulumi_azure.authorization",
  "classes": {
   "azure:authorization/roleDefinition:RoleDefinition": "RoleDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "authorization/userAssignedIdentity",
  "fqn": "pulumi_azure.authorization",
  "classes": {
   "azure:authorization/userAssignedIdentity:UserAssignedIdentity": "UserAssignedIdentity"
  }
 },
 {
  "pkg": "azure",
  "mod": "automanage/configuration",
  "fqn": "pulumi_azure.automanage",
  "classes": {
   "azure:automanage/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/account",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/boolVariable",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/boolVariable:BoolVariable": "BoolVariable"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/certificate",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/connection",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/connectionCertificate",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/connectionCertificate:ConnectionCertificate": "ConnectionCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/connectionClassicCertificate",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/connectionClassicCertificate:ConnectionClassicCertificate": "ConnectionClassicCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/connectionServicePrincipal",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/connectionServicePrincipal:ConnectionServicePrincipal": "ConnectionServicePrincipal"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/connectionType",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/connectionType:ConnectionType": "ConnectionType"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/credential",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/credential:Credential": "Credential"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/dateTimeVariable",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/dateTimeVariable:DateTimeVariable": "DateTimeVariable"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/dscConfiguration",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/dscConfiguration:DscConfiguration": "DscConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/dscNodeConfiguration",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/dscNodeConfiguration:DscNodeConfiguration": "DscNodeConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/hybridRunbookWorker",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/hybridRunbookWorker:HybridRunbookWorker": "HybridRunbookWorker"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/hybridRunbookWorkerGroup",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/hybridRunbookWorkerGroup:HybridRunbookWorkerGroup": "HybridRunbookWorkerGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/intVariable",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/intVariable:IntVariable": "IntVariable"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/jobSchedule",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/jobSchedule:JobSchedule": "JobSchedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/module",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/module:Module": "Module"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/powershell72Module",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/powershell72Module:Powershell72Module": "Powershell72Module"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/python3Package",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/python3Package:Python3Package": "Python3Package"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/runBook",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/runBook:RunBook": "RunBook"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/schedule",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/schedule:Schedule": "Schedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/softwareUpdateConfiguration",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/softwareUpdateConfiguration:SoftwareUpdateConfiguration": "SoftwareUpdateConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/sourceControl",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/sourceControl:SourceControl": "SourceControl"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/stringVariable",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/stringVariable:StringVariable": "StringVariable"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/variableObject",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/variableObject:VariableObject": "VariableObject"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/watcher",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/watcher:Watcher": "Watcher"
  }
 },
 {
  "pkg": "azure",
  "mod": "automation/webhook",
  "fqn": "pulumi_azure.automation",
  "classes": {
   "azure:automation/webhook:Webhook": "Webhook"
  }
 },
 {
  "pkg": "azure",
  "mod": "avs/cluster",
  "fqn": "pulumi_azure.avs",
  "classes": {
   "azure:avs/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "avs/expressRouteAuthorization",
  "fqn": "pulumi_azure.avs",
  "classes": {
   "azure:avs/expressRouteAuthorization:ExpressRouteAuthorization": "ExpressRouteAuthorization"
  }
 },
 {
  "pkg": "azure",
  "mod": "avs/netappVolumeAttachment",
  "fqn": "pulumi_azure.avs",
  "classes": {
   "azure:avs/netappVolumeAttachment:NetappVolumeAttachment": "NetappVolumeAttachment"
  }
 },
 {
  "pkg": "azure",
  "mod": "avs/privateCloud",
  "fqn": "pulumi_azure.avs",
  "classes": {
   "azure:avs/privateCloud:PrivateCloud": "PrivateCloud"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/containerStorageAccount",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/containerStorageAccount:ContainerStorageAccount": "ContainerStorageAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/policyFileShare",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/policyFileShare:PolicyFileShare": "PolicyFileShare"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/policyVM",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/policyVM:PolicyVM": "PolicyVM"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/policyVMWorkload",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/policyVMWorkload:PolicyVMWorkload": "PolicyVMWorkload"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/protectedFileShare",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/protectedFileShare:ProtectedFileShare": "ProtectedFileShare"
  }
 },
 {
  "pkg": "azure",
  "mod": "backup/protectedVM",
  "fqn": "pulumi_azure.backup",
  "classes": {
   "azure:backup/protectedVM:ProtectedVM": "ProtectedVM"
  }
 },
 {
  "pkg": "azure",
  "mod": "batch/account",
  "fqn": "pulumi_azure.batch",
  "classes": {
   "azure:batch/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "batch/application",
  "fqn": "pulumi_azure.batch",
  "classes": {
   "azure:batch/application:Application": "Application"
  }
 },
 {
  "pkg": "azure",
  "mod": "batch/certificate",
  "fqn": "pulumi_azure.batch",
  "classes": {
   "azure:batch/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "batch/job",
  "fqn": "pulumi_azure.batch",
  "classes": {
   "azure:batch/job:Job": "Job"
  }
 },
 {
  "pkg": "azure",
  "mod": "batch/pool",
  "fqn": "pulumi_azure.batch",
  "classes": {
   "azure:batch/pool:Pool": "Pool"
  }
 },
 {
  "pkg": "azure",
  "mod": "billing/accountCostManagementExport",
  "fqn": "pulumi_azure.billing",
  "classes": {
   "azure:billing/accountCostManagementExport:AccountCostManagementExport": "AccountCostManagementExport"
  }
 },
 {
  "pkg": "azure",
  "mod": "blueprint/assignment",
  "fqn": "pulumi_azure.blueprint",
  "classes": {
   "azure:blueprint/assignment:Assignment": "Assignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelAlexa",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelAlexa:ChannelAlexa": "ChannelAlexa"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelDirectLine",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelDirectLine:ChannelDirectLine": "ChannelDirectLine"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelDirectLineSpeech",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelDirectLineSpeech:ChannelDirectLineSpeech": "ChannelDirectLineSpeech"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelEmail",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelEmail:ChannelEmail": "ChannelEmail"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelFacebook",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelFacebook:ChannelFacebook": "ChannelFacebook"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelLine",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelLine:ChannelLine": "ChannelLine"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelSlack",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelSlack:ChannelSlack": "ChannelSlack"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelSms",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelSms:ChannelSms": "ChannelSms"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelTeams",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelTeams:ChannelTeams": "ChannelTeams"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelWebChat",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelWebChat:ChannelWebChat": "ChannelWebChat"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/channelsRegistration",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/channelsRegistration:ChannelsRegistration": "ChannelsRegistration"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/connection",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/healthbot",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/healthbot:Healthbot": "Healthbot"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/serviceAzureBot",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/serviceAzureBot:ServiceAzureBot": "ServiceAzureBot"
  }
 },
 {
  "pkg": "azure",
  "mod": "bot/webApp",
  "fqn": "pulumi_azure.bot",
  "classes": {
   "azure:bot/webApp:WebApp": "WebApp"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/endpoint",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/endpointCustomDomain",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/endpointCustomDomain:EndpointCustomDomain": "EndpointCustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorCustomDomain",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorCustomDomain:FrontdoorCustomDomain": "FrontdoorCustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorCustomDomainAssociation",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorCustomDomainAssociation:FrontdoorCustomDomainAssociation": "FrontdoorCustomDomainAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorEndpoint",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorEndpoint:FrontdoorEndpoint": "FrontdoorEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorFirewallPolicy",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorFirewallPolicy:FrontdoorFirewallPolicy": "FrontdoorFirewallPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorOrigin",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorOrigin:FrontdoorOrigin": "FrontdoorOrigin"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorOriginGroup",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorOriginGroup:FrontdoorOriginGroup": "FrontdoorOriginGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorProfile",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorProfile:FrontdoorProfile": "FrontdoorProfile"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorRoute",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorRoute:FrontdoorRoute": "FrontdoorRoute"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorRule",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorRule:FrontdoorRule": "FrontdoorRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorRuleSet",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorRuleSet:FrontdoorRuleSet": "FrontdoorRuleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorSecret",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorSecret:FrontdoorSecret": "FrontdoorSecret"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/frontdoorSecurityPolicy",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/frontdoorSecurityPolicy:FrontdoorSecurityPolicy": "FrontdoorSecurityPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "cdn/profile",
  "fqn": "pulumi_azure.cdn",
  "classes": {
   "azure:cdn/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "azure",
  "mod": "chaosstudio/capability",
  "fqn": "pulumi_azure.chaosstudio",
  "classes": {
   "azure:chaosstudio/capability:Capability": "Capability"
  }
 },
 {
  "pkg": "azure",
  "mod": "chaosstudio/experiment",
  "fqn": "pulumi_azure.chaosstudio",
  "classes": {
   "azure:chaosstudio/experiment:Experiment": "Experiment"
  }
 },
 {
  "pkg": "azure",
  "mod": "chaosstudio/target",
  "fqn": "pulumi_azure.chaosstudio",
  "classes": {
   "azure:chaosstudio/target:Target": "Target"
  }
 },
 {
  "pkg": "azure",
  "mod": "cognitive/aIServices",
  "fqn": "pulumi_azure.cognitive",
  "classes": {
   "azure:cognitive/aIServices:AIServices": "AIServices"
  }
 },
 {
  "pkg": "azure",
  "mod": "cognitive/account",
  "fqn": "pulumi_azure.cognitive",
  "classes": {
   "azure:cognitive/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "cognitive/accountCustomerManagedKey",
  "fqn": "pulumi_azure.cognitive",
  "classes": {
   "azure:cognitive/accountCustomerManagedKey:AccountCustomerManagedKey": "AccountCustomerManagedKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "cognitive/accountRaiBlocklist",
  "fqn": "pulumi_azure.cognitive",
  "classes": {
   "azure:cognitive/accountRaiBlocklist:AccountRaiBlocklist": "AccountRaiBlocklist"
  }
 },
 {
  "pkg": "azure",
  "mod": "cognitive/deployment",
  "fqn": "pulumi_azure.cognitive",
  "classes": {
   "azure:cognitive/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "communication/emailService",
  "fqn": "pulumi_azure.communication",
  "classes": {
   "azure:communication/emailService:EmailService": "EmailService"
  }
 },
 {
  "pkg": "azure",
  "mod": "communication/emailServiceDomain",
  "fqn": "pulumi_azure.communication",
  "classes": {
   "azure:communication/emailServiceDomain:EmailServiceDomain": "EmailServiceDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "communication/service",
  "fqn": "pulumi_azure.communication",
  "classes": {
   "azure:communication/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "communication/serviceEmailDomainAssociation",
  "fqn": "pulumi_azure.communication",
  "classes": {
   "azure:communication/serviceEmailDomainAssociation:ServiceEmailDomainAssociation": "ServiceEmailDomainAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/automanageConfigurationAssignment",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/automanageConfigurationAssignment:AutomanageConfigurationAssignment": "AutomanageConfigurationAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/availabilitySet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/availabilitySet:AvailabilitySet": "AvailabilitySet"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/bastionHost",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/bastionHost:BastionHost": "BastionHost"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/capacityReservation",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/capacityReservation:CapacityReservation": "CapacityReservation"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/capacityReservationGroup",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/capacityReservationGroup:CapacityReservationGroup": "CapacityReservationGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/dataDiskAttachment",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/dataDiskAttachment:DataDiskAttachment": "DataDiskAttachment"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/dedicatedHost",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/dedicatedHost:DedicatedHost": "DedicatedHost"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/dedicatedHostGroup",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/dedicatedHostGroup:DedicatedHostGroup": "DedicatedHostGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/diskAccess",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/diskAccess:DiskAccess": "DiskAccess"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/diskEncryptionSet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/diskEncryptionSet:DiskEncryptionSet": "DiskEncryptionSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/extension",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/extension:Extension": "Extension"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/galleryApplication",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/galleryApplication:GalleryApplication": "GalleryApplication"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/galleryApplicationAssignment",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/galleryApplicationAssignment:GalleryApplicationAssignment": "GalleryApplicationAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/galleryApplicationVersion",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/galleryApplicationVersion:GalleryApplicationVersion": "GalleryApplicationVersion"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/image",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/image:Image": "Image"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/implicitDataDiskFromSource",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/implicitDataDiskFromSource:ImplicitDataDiskFromSource": "ImplicitDataDiskFromSource"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/linuxVirtualMachine",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/linuxVirtualMachine:LinuxVirtualMachine": "LinuxVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/linuxVirtualMachineScaleSet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/linuxVirtualMachineScaleSet:LinuxVirtualMachineScaleSet": "LinuxVirtualMachineScaleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/managedDisk",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/managedDisk:ManagedDisk": "ManagedDisk"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/managedDiskSasToken",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/managedDiskSasToken:ManagedDiskSasToken": "ManagedDiskSasToken"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/orchestratedVirtualMachineScaleSet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/orchestratedVirtualMachineScaleSet:OrchestratedVirtualMachineScaleSet": "OrchestratedVirtualMachineScaleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/packetCapture",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/packetCapture:PacketCapture": "PacketCapture"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/restorePoint",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/restorePoint:RestorePoint": "RestorePoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/restorePointCollection",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/restorePointCollection:RestorePointCollection": "RestorePointCollection"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/runCommand",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/runCommand:RunCommand": "RunCommand"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/scaleSet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/scaleSet:ScaleSet": "ScaleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/scaleSetPacketCapture",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/scaleSetPacketCapture:ScaleSetPacketCapture": "ScaleSetPacketCapture"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/sharedImage",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/sharedImage:SharedImage": "SharedImage"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/sharedImageGallery",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/sharedImageGallery:SharedImageGallery": "SharedImageGallery"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/sharedImageVersion",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/sharedImageVersion:SharedImageVersion": "SharedImageVersion"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/snapshot",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/sshPublicKey",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/sshPublicKey:SshPublicKey": "SshPublicKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/virtualMachine",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/virtualMachine:VirtualMachine": "VirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/virtualMachineScaleSetExtension",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/virtualMachineScaleSetExtension:VirtualMachineScaleSetExtension": "VirtualMachineScaleSetExtension"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/windowsVirtualMachine",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/windowsVirtualMachine:WindowsVirtualMachine": "WindowsVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "compute/windowsVirtualMachineScaleSet",
  "fqn": "pulumi_azure.compute",
  "classes": {
   "azure:compute/windowsVirtualMachineScaleSet:WindowsVirtualMachineScaleSet": "WindowsVirtualMachineScaleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "confidentialledger/ledger",
  "fqn": "pulumi_azure.confidentialledger",
  "classes": {
   "azure:confidentialledger/ledger:Ledger": "Ledger"
  }
 },
 {
  "pkg": "azure",
  "mod": "connections/apiConnection",
  "fqn": "pulumi_azure.connections",
  "classes": {
   "azure:connections/apiConnection:ApiConnection": "ApiConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "consumption/budgetManagementGroup",
  "fqn": "pulumi_azure.consumption",
  "classes": {
   "azure:consumption/budgetManagementGroup:BudgetManagementGroup": "BudgetManagementGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "consumption/budgetResourceGroup",
  "fqn": "pulumi_azure.consumption",
  "classes": {
   "azure:consumption/budgetResourceGroup:BudgetResourceGroup": "BudgetResourceGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "consumption/budgetSubscription",
  "fqn": "pulumi_azure.consumption",
  "classes": {
   "azure:consumption/budgetSubscription:BudgetSubscription": "BudgetSubscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerapp/app",
  "fqn": "pulumi_azure.containerapp",
  "classes": {
   "azure:containerapp/app:App": "App"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerapp/customDomain",
  "fqn": "pulumi_azure.containerapp",
  "classes": {
   "azure:containerapp/customDomain:CustomDomain": "CustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerapp/environment",
  "fqn": "pulumi_azure.containerapp",
  "classes": {
   "azure:containerapp/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerapp/environmentCertificate",
  "fqn": "pulumi_azure.containerapp",
  "classes": {
   "azure:containerapp/environmentCertificate:EnvironmentCertificate": "EnvironmentCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerapp/environmentCustomDomain",
  "fqn": "pulumi_azure.containerapp",
  "classes": {
   "azure:containerapp/environmentCustomDomain:EnvironmentCustomDomain": "EnvironmentCustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerapp/environmentDaprComponent",
  "fqn": "pulumi_azure.containerapp",
  "classes": {
   "azure:containerapp/environmentDaprComponent:EnvironmentDaprComponent": "EnvironmentDaprComponent"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerapp/environmentStorage",
  "fqn": "pulumi_azure.containerapp",
  "classes": {
   "azure:containerapp/environmentStorage:EnvironmentStorage": "EnvironmentStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerapp/job",
  "fqn": "pulumi_azure.containerapp",
  "classes": {
   "azure:containerapp/job:Job": "Job"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/clusterTrustedAccessRoleBinding",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/clusterTrustedAccessRoleBinding:ClusterTrustedAccessRoleBinding": "ClusterTrustedAccessRoleBinding"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/connectedRegistry",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/connectedRegistry:ConnectedRegistry": "ConnectedRegistry"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/fleetMember",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/fleetMember:FleetMember": "FleetMember"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/fleetUpdateRun",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/fleetUpdateRun:FleetUpdateRun": "FleetUpdateRun"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/fleetUpdateStrategy",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/fleetUpdateStrategy:FleetUpdateStrategy": "FleetUpdateStrategy"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/fluxConfiguration",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/fluxConfiguration:FluxConfiguration": "FluxConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/group",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/group:Group": "Group"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/kubernetesCluster",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/kubernetesCluster:KubernetesCluster": "KubernetesCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/kubernetesClusterExtension",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/kubernetesClusterExtension:KubernetesClusterExtension": "KubernetesClusterExtension"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/kubernetesClusterNodePool",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/kubernetesClusterNodePool:KubernetesClusterNodePool": "KubernetesClusterNodePool"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/kubernetesFleetManager",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/kubernetesFleetManager:KubernetesFleetManager": "KubernetesFleetManager"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registry",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registry:Registry": "Registry"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryAgentPool",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryAgentPool:RegistryAgentPool": "RegistryAgentPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryCacheRule",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryCacheRule:RegistryCacheRule": "RegistryCacheRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryCredentialSet",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryCredentialSet:RegistryCredentialSet": "RegistryCredentialSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryScopeMap",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryScopeMap:RegistryScopeMap": "RegistryScopeMap"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryTask",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryTask:RegistryTask": "RegistryTask"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryTaskScheduleRunNow",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryTaskScheduleRunNow:RegistryTaskScheduleRunNow": "RegistryTaskScheduleRunNow"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryToken",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryToken:RegistryToken": "RegistryToken"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryWebhook",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryWebhook:RegistryWebhook": "RegistryWebhook"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/registryWebook",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/registryWebook:RegistryWebook": "RegistryWebook"
  }
 },
 {
  "pkg": "azure",
  "mod": "containerservice/tokenPassword",
  "fqn": "pulumi_azure.containerservice",
  "classes": {
   "azure:containerservice/tokenPassword:TokenPassword": "TokenPassword"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/customProvider",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/customProvider:CustomProvider": "CustomProvider"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/portalTenantConfiguration",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/portalTenantConfiguration:PortalTenantConfiguration": "PortalTenantConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceDeploymentScriptAzureCli",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceDeploymentScriptAzureCli:ResourceDeploymentScriptAzureCli": "ResourceDeploymentScriptAzureCli"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceDeploymentScriptPowerShell",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceDeploymentScriptPowerShell:ResourceDeploymentScriptPowerShell": "ResourceDeploymentScriptPowerShell"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceGroup",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceGroup:ResourceGroup": "ResourceGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceGroupCostManagementExport",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceGroupCostManagementExport:ResourceGroupCostManagementExport": "ResourceGroupCostManagementExport"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceGroupCostManagementView",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceGroupCostManagementView:ResourceGroupCostManagementView": "ResourceGroupCostManagementView"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceGroupPolicyAssignment",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceGroupPolicyAssignment:ResourceGroupPolicyAssignment": "ResourceGroupPolicyAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceGroupPolicyExemption",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceGroupPolicyExemption:ResourceGroupPolicyExemption": "ResourceGroupPolicyExemption"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceGroupPolicyRemediation",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceGroupPolicyRemediation:ResourceGroupPolicyRemediation": "ResourceGroupPolicyRemediation"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceGroupTemplateDeployment",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceGroupTemplateDeployment:ResourceGroupTemplateDeployment": "ResourceGroupTemplateDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourcePolicyAssignment",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourcePolicyAssignment:ResourcePolicyAssignment": "ResourcePolicyAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourcePolicyExemption",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourcePolicyExemption:ResourcePolicyExemption": "ResourcePolicyExemption"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourcePolicyRemediation",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourcePolicyRemediation:ResourcePolicyRemediation": "ResourcePolicyRemediation"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/resourceProviderRegistration",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/resourceProviderRegistration:ResourceProviderRegistration": "ResourceProviderRegistration"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/subscription",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/subscriptionCostManagementExport",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/subscriptionCostManagementExport:SubscriptionCostManagementExport": "SubscriptionCostManagementExport"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/subscriptionCostManagementView",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/subscriptionCostManagementView:SubscriptionCostManagementView": "SubscriptionCostManagementView"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/subscriptionPolicyAssignment",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/subscriptionPolicyAssignment:SubscriptionPolicyAssignment": "SubscriptionPolicyAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/subscriptionPolicyExemption",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/subscriptionPolicyExemption:SubscriptionPolicyExemption": "SubscriptionPolicyExemption"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/subscriptionPolicyRemediation",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/subscriptionPolicyRemediation:SubscriptionPolicyRemediation": "SubscriptionPolicyRemediation"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/subscriptionTemplateDeployment",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/subscriptionTemplateDeployment:SubscriptionTemplateDeployment": "SubscriptionTemplateDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "core/tenantTemplateDeployment",
  "fqn": "pulumi_azure.core",
  "classes": {
   "azure:core/tenantTemplateDeployment:TenantTemplateDeployment": "TenantTemplateDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/account",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/cassandraCluster",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/cassandraCluster:CassandraCluster": "CassandraCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/cassandraDatacenter",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/cassandraDatacenter:CassandraDatacenter": "CassandraDatacenter"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/cassandraKeyspace",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/cassandraKeyspace:CassandraKeyspace": "CassandraKeyspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/cassandraTable",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/cassandraTable:CassandraTable": "CassandraTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/gremlinDatabase",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/gremlinDatabase:GremlinDatabase": "GremlinDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/gremlinGraph",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/gremlinGraph:GremlinGraph": "GremlinGraph"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/mongoCluster",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/mongoCluster:MongoCluster": "MongoCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/mongoCollection",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/mongoCollection:MongoCollection": "MongoCollection"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/mongoDatabase",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/mongoDatabase:MongoDatabase": "MongoDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/mongoRoleDefinition",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/mongoRoleDefinition:MongoRoleDefinition": "MongoRoleDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/mongoUserDefinition",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/mongoUserDefinition:MongoUserDefinition": "MongoUserDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/postgresqlCluster",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/postgresqlCluster:PostgresqlCluster": "PostgresqlCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/postgresqlCoordinatorConfiguration",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/postgresqlCoordinatorConfiguration:PostgresqlCoordinatorConfiguration": "PostgresqlCoordinatorConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/postgresqlFirewallRule",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/postgresqlFirewallRule:PostgresqlFirewallRule": "PostgresqlFirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/postgresqlNodeConfiguration",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/postgresqlNodeConfiguration:PostgresqlNodeConfiguration": "PostgresqlNodeConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/postgresqlRole",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/postgresqlRole:PostgresqlRole": "PostgresqlRole"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlContainer",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlContainer:SqlContainer": "SqlContainer"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlDatabase",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlDatabase:SqlDatabase": "SqlDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlDedicatedGateway",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlDedicatedGateway:SqlDedicatedGateway": "SqlDedicatedGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlFunction",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlFunction:SqlFunction": "SqlFunction"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlRoleAssignment",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlRoleAssignment:SqlRoleAssignment": "SqlRoleAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlRoleDefinition",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlRoleDefinition:SqlRoleDefinition": "SqlRoleDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlStoredProcedure",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlStoredProcedure:SqlStoredProcedure": "SqlStoredProcedure"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/sqlTrigger",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/sqlTrigger:SqlTrigger": "SqlTrigger"
  }
 },
 {
  "pkg": "azure",
  "mod": "cosmosdb/table",
  "fqn": "pulumi_azure.cosmosdb",
  "classes": {
   "azure:cosmosdb/table:Table": "Table"
  }
 },
 {
  "pkg": "azure",
  "mod": "costmanagement/anomalyAlert",
  "fqn": "pulumi_azure.costmanagement",
  "classes": {
   "azure:costmanagement/anomalyAlert:AnomalyAlert": "AnomalyAlert"
  }
 },
 {
  "pkg": "azure",
  "mod": "costmanagement/scheduledAction",
  "fqn": "pulumi_azure.costmanagement",
  "classes": {
   "azure:costmanagement/scheduledAction:ScheduledAction": "ScheduledAction"
  }
 },
 {
  "pkg": "azure",
  "mod": "customip/prefix",
  "fqn": "pulumi_azure.customip",
  "classes": {
   "azure:customip/prefix:Prefix": "Prefix"
  }
 },
 {
  "pkg": "azure",
  "mod": "dashboard/grafana",
  "fqn": "pulumi_azure.dashboard",
  "classes": {
   "azure:dashboard/grafana:Grafana": "Grafana"
  }
 },
 {
  "pkg": "azure",
  "mod": "dashboard/grafanaManagedPrivateEndpoint",
  "fqn": "pulumi_azure.dashboard",
  "classes": {
   "azure:dashboard/grafanaManagedPrivateEndpoint:GrafanaManagedPrivateEndpoint": "GrafanaManagedPrivateEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "databasemigration/project",
  "fqn": "pulumi_azure.databasemigration",
  "classes": {
   "azure:databasemigration/project:Project": "Project"
  }
 },
 {
  "pkg": "azure",
  "mod": "databasemigration/service",
  "fqn": "pulumi_azure.databasemigration",
  "classes": {
   "azure:databasemigration/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "databoxedge/device",
  "fqn": "pulumi_azure.databoxedge",
  "classes": {
   "azure:databoxedge/device:Device": "Device"
  }
 },
 {
  "pkg": "azure",
  "mod": "databricks/accessConnector",
  "fqn": "pulumi_azure.databricks",
  "classes": {
   "azure:databricks/accessConnector:AccessConnector": "AccessConnector"
  }
 },
 {
  "pkg": "azure",
  "mod": "databricks/virtualNetworkPeering",
  "fqn": "pulumi_azure.databricks",
  "classes": {
   "azure:databricks/virtualNetworkPeering:VirtualNetworkPeering": "VirtualNetworkPeering"
  }
 },
 {
  "pkg": "azure",
  "mod": "databricks/workspace",
  "fqn": "pulumi_azure.databricks",
  "classes": {
   "azure:databricks/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "databricks/workspaceCustomerManagedKey",
  "fqn": "pulumi_azure.databricks",
  "classes": {
   "azure:databricks/workspaceCustomerManagedKey:WorkspaceCustomerManagedKey": "WorkspaceCustomerManagedKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "databricks/workspaceRootDbfsCustomerManagedKey",
  "fqn": "pulumi_azure.databricks",
  "classes": {
   "azure:databricks/workspaceRootDbfsCustomerManagedKey:WorkspaceRootDbfsCustomerManagedKey": "WorkspaceRootDbfsCustomerManagedKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "datadog/monitor",
  "fqn": "pulumi_azure.datadog",
  "classes": {
   "azure:datadog/monitor:Monitor": "Monitor"
  }
 },
 {
  "pkg": "azure",
  "mod": "datadog/monitorSsoConfiguration",
  "fqn": "pulumi_azure.datadog",
  "classes": {
   "azure:datadog/monitorSsoConfiguration:MonitorSsoConfiguration": "MonitorSsoConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "datadog/monitorTagRule",
  "fqn": "pulumi_azure.datadog",
  "classes": {
   "azure:datadog/monitorTagRule:MonitorTagRule": "MonitorTagRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/credentialServicePrincipal",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/credentialServicePrincipal:CredentialServicePrincipal": "CredentialServicePrincipal"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/credentialUserManagedIdentity",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/credentialUserManagedIdentity:CredentialUserManagedIdentity": "CredentialUserManagedIdentity"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/customDataset",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/customDataset:CustomDataset": "CustomDataset"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/dataFlow",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/dataFlow:DataFlow": "DataFlow"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetAzureBlob",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetAzureBlob:DatasetAzureBlob": "DatasetAzureBlob"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetAzureSqlTable",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetAzureSqlTable:DatasetAzureSqlTable": "DatasetAzureSqlTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetBinary",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetBinary:DatasetBinary": "DatasetBinary"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetCosmosDBApi",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetCosmosDBApi:DatasetCosmosDBApi": "DatasetCosmosDBApi"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetDelimitedText",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetDelimitedText:DatasetDelimitedText": "DatasetDelimitedText"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetHttp",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetHttp:DatasetHttp": "DatasetHttp"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetJson",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetJson:DatasetJson": "DatasetJson"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetMysql",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetMysql:DatasetMysql": "DatasetMysql"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetParquet",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetParquet:DatasetParquet": "DatasetParquet"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetPostgresql",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetPostgresql:DatasetPostgresql": "DatasetPostgresql"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetSnowflake",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetSnowflake:DatasetSnowflake": "DatasetSnowflake"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/datasetSqlServerTable",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/datasetSqlServerTable:DatasetSqlServerTable": "DatasetSqlServerTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/factory",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/factory:Factory": "Factory"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/flowletDataFlow",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/flowletDataFlow:FlowletDataFlow": "FlowletDataFlow"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/integrationRuntimeRule",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/integrationRuntimeRule:IntegrationRuntimeRule": "IntegrationRuntimeRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/integrationRuntimeSelfHosted",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/integrationRuntimeSelfHosted:IntegrationRuntimeSelfHosted": "IntegrationRuntimeSelfHosted"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/integrationRuntimeSsis",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/integrationRuntimeSsis:IntegrationRuntimeSsis": "IntegrationRuntimeSsis"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedCustomService",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedCustomService:LinkedCustomService": "LinkedCustomService"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureBlobStorage",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureBlobStorage:LinkedServiceAzureBlobStorage": "LinkedServiceAzureBlobStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureDatabricks",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureDatabricks:LinkedServiceAzureDatabricks": "LinkedServiceAzureDatabricks"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureFileStorage",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureFileStorage:LinkedServiceAzureFileStorage": "LinkedServiceAzureFileStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureFunction",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureFunction:LinkedServiceAzureFunction": "LinkedServiceAzureFunction"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureSearch",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureSearch:LinkedServiceAzureSearch": "LinkedServiceAzureSearch"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureSqlDatabase",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureSqlDatabase:LinkedServiceAzureSqlDatabase": "LinkedServiceAzureSqlDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceAzureTableStorage",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceAzureTableStorage:LinkedServiceAzureTableStorage": "LinkedServiceAzureTableStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceCosmosDb",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceCosmosDb:LinkedServiceCosmosDb": "LinkedServiceCosmosDb"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceCosmosDbMongoApi",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceCosmosDbMongoApi:LinkedServiceCosmosDbMongoApi": "LinkedServiceCosmosDbMongoApi"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceDataLakeStorageGen2",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceDataLakeStorageGen2:LinkedServiceDataLakeStorageGen2": "LinkedServiceDataLakeStorageGen2"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceKeyVault",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceKeyVault:LinkedServiceKeyVault": "LinkedServiceKeyVault"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceKusto",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceKusto:LinkedServiceKusto": "LinkedServiceKusto"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceMysql",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceMysql:LinkedServiceMysql": "LinkedServiceMysql"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceOdata",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceOdata:LinkedServiceOdata": "LinkedServiceOdata"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceOdbc",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceOdbc:LinkedServiceOdbc": "LinkedServiceOdbc"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServicePostgresql",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServicePostgresql:LinkedServicePostgresql": "LinkedServicePostgresql"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceSftp",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceSftp:LinkedServiceSftp": "LinkedServiceSftp"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceSnowflake",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceSnowflake:LinkedServiceSnowflake": "LinkedServiceSnowflake"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceSqlServer",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceSqlServer:LinkedServiceSqlServer": "LinkedServiceSqlServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceSynapse",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceSynapse:LinkedServiceSynapse": "LinkedServiceSynapse"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/linkedServiceWeb",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/linkedServiceWeb:LinkedServiceWeb": "LinkedServiceWeb"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/managedPrivateEndpoint",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/managedPrivateEndpoint:ManagedPrivateEndpoint": "ManagedPrivateEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/pipeline",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/pipeline:Pipeline": "Pipeline"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/triggerBlobEvent",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/triggerBlobEvent:TriggerBlobEvent": "TriggerBlobEvent"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/triggerCustomEvent",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/triggerCustomEvent:TriggerCustomEvent": "TriggerCustomEvent"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/triggerSchedule",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/triggerSchedule:TriggerSchedule": "TriggerSchedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "datafactory/triggerTumblingWindow",
  "fqn": "pulumi_azure.datafactory",
  "classes": {
   "azure:datafactory/triggerTumblingWindow:TriggerTumblingWindow": "TriggerTumblingWindow"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupInstanceBlogStorage",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupInstanceBlogStorage:BackupInstanceBlogStorage": "BackupInstanceBlogStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupInstanceDisk",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupInstanceDisk:BackupInstanceDisk": "BackupInstanceDisk"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupInstanceKubernetesCluster",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupInstanceKubernetesCluster:BackupInstanceKubernetesCluster": "BackupInstanceKubernetesCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupInstanceMysqlFlexibleServer",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupInstanceMysqlFlexibleServer:BackupInstanceMysqlFlexibleServer": "BackupInstanceMysqlFlexibleServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupInstancePostgresql",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupInstancePostgresql:BackupInstancePostgresql": "BackupInstancePostgresql"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupInstancePostgresqlFlexibleServer",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupInstancePostgresqlFlexibleServer:BackupInstancePostgresqlFlexibleServer": "BackupInstancePostgresqlFlexibleServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupPolicyBlobStorage",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupPolicyBlobStorage:BackupPolicyBlobStorage": "BackupPolicyBlobStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupPolicyDisk",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupPolicyDisk:BackupPolicyDisk": "BackupPolicyDisk"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupPolicyKubernetesCluster",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupPolicyKubernetesCluster:BackupPolicyKubernetesCluster": "BackupPolicyKubernetesCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupPolicyMysqlFlexibleServer",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupPolicyMysqlFlexibleServer:BackupPolicyMysqlFlexibleServer": "BackupPolicyMysqlFlexibleServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupPolicyPostgresql",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupPolicyPostgresql:BackupPolicyPostgresql": "BackupPolicyPostgresql"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupPolicyPostgresqlFlexibleServer",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupPolicyPostgresqlFlexibleServer:BackupPolicyPostgresqlFlexibleServer": "BackupPolicyPostgresqlFlexibleServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/backupVault",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/backupVault:BackupVault": "BackupVault"
  }
 },
 {
  "pkg": "azure",
  "mod": "dataprotection/resourceGuard",
  "fqn": "pulumi_azure.dataprotection",
  "classes": {
   "azure:dataprotection/resourceGuard:ResourceGuard": "ResourceGuard"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/account",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/datasetBlobStorage",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/datasetBlobStorage:DatasetBlobStorage": "DatasetBlobStorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/datasetDataLakeGen2",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/datasetDataLakeGen2:DatasetDataLakeGen2": "DatasetDataLakeGen2"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/datasetKustoCluster",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/datasetKustoCluster:DatasetKustoCluster": "DatasetKustoCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/datasetKustoDatabase",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/datasetKustoDatabase:DatasetKustoDatabase": "DatasetKustoDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "datashare/share",
  "fqn": "pulumi_azure.datashare",
  "classes": {
   "azure:datashare/share:Share": "Share"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/application",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/application:Application": "Application"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/applicationGroup",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/applicationGroup:ApplicationGroup": "ApplicationGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/getHostPoolRegistrationInfo",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/getHostPoolRegistrationInfo:getHostPoolRegistrationInfo": "GetHostPoolRegistrationInfo"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/hostPool",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/hostPool:HostPool": "HostPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/scalingPlan",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/scalingPlan:ScalingPlan": "ScalingPlan"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/scalingPlanHostPoolAssociation",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/scalingPlanHostPoolAssociation:ScalingPlanHostPoolAssociation": "ScalingPlanHostPoolAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/workspace",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "desktopvirtualization/workspaceApplicationGroupAssociation",
  "fqn": "pulumi_azure.desktopvirtualization",
  "classes": {
   "azure:desktopvirtualization/workspaceApplicationGroupAssociation:WorkspaceApplicationGroupAssociation": "WorkspaceApplicationGroupAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "devcenter/attachedNetwork",
  "fqn": "pulumi_azure.devcenter",
  "classes": {
   "azure:devcenter/attachedNetwork:AttachedNetwork": "AttachedNetwork"
  }
 },
 {
  "pkg": "azure",
  "mod": "devcenter/catalog",
  "fqn": "pulumi_azure.devcenter",
  "classes": {
   "azure:devcenter/catalog:Catalog": "Catalog"
  }
 },
 {
  "pkg": "azure",
  "mod": "devcenter/devBoxDefinition",
  "fqn": "pulumi_azure.devcenter",
  "classes": {
   "azure:devcenter/devBoxDefinition:DevBoxDefinition": "DevBoxDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "devcenter/devCenter",
  "fqn": "pulumi_azure.devcenter",
  "classes": {
   "azure:devcenter/devCenter:DevCenter": "DevCenter"
  }
 },
 {
  "pkg": "azure",
  "mod": "devcenter/environmentType",
  "fqn": "pulumi_azure.devcenter",
  "classes": {
   "azure:devcenter/environmentType:EnvironmentType": "EnvironmentType"
  }
 },
 {
  "pkg": "azure",
  "mod": "devcenter/gallery",
  "fqn": "pulumi_azure.devcenter",
  "classes": {
   "azure:devcenter/gallery:Gallery": "Gallery"
  }
 },
 {
  "pkg": "azure",
  "mod": "devcenter/networkConnection",
  "fqn": "pulumi_azure.devcenter",
  "classes": {
   "azure:devcenter/networkConnection:NetworkConnection": "NetworkConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "devcenter/project",
  "fqn": "pulumi_azure.devcenter",
  "classes": {
   "azure:devcenter/project:Project": "Project"
  }
 },
 {
  "pkg": "azure",
  "mod": "devcenter/projectEnvironmentType",
  "fqn": "pulumi_azure.devcenter",
  "classes": {
   "azure:devcenter/projectEnvironmentType:ProjectEnvironmentType": "ProjectEnvironmentType"
  }
 },
 {
  "pkg": "azure",
  "mod": "devcenter/projectPool",
  "fqn": "pulumi_azure.devcenter",
  "classes": {
   "azure:devcenter/projectPool:ProjectPool": "ProjectPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/globalVMShutdownSchedule",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/globalVMShutdownSchedule:GlobalVMShutdownSchedule": "GlobalVMShutdownSchedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/lab",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/lab:Lab": "Lab"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/linuxVirtualMachine",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/linuxVirtualMachine:LinuxVirtualMachine": "LinuxVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/policy",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/schedule",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/schedule:Schedule": "Schedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/virtualNetwork",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/virtualNetwork:VirtualNetwork": "VirtualNetwork"
  }
 },
 {
  "pkg": "azure",
  "mod": "devtest/windowsVirtualMachine",
  "fqn": "pulumi_azure.devtest",
  "classes": {
   "azure:devtest/windowsVirtualMachine:WindowsVirtualMachine": "WindowsVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "digitaltwins/endpointEventGrid",
  "fqn": "pulumi_azure.digitaltwins",
  "classes": {
   "azure:digitaltwins/endpointEventGrid:EndpointEventGrid": "EndpointEventGrid"
  }
 },
 {
  "pkg": "azure",
  "mod": "digitaltwins/endpointEventHub",
  "fqn": "pulumi_azure.digitaltwins",
  "classes": {
   "azure:digitaltwins/endpointEventHub:EndpointEventHub": "EndpointEventHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "digitaltwins/endpointServicebus",
  "fqn": "pulumi_azure.digitaltwins",
  "classes": {
   "azure:digitaltwins/endpointServicebus:EndpointServicebus": "EndpointServicebus"
  }
 },
 {
  "pkg": "azure",
  "mod": "digitaltwins/instance",
  "fqn": "pulumi_azure.digitaltwins",
  "classes": {
   "azure:digitaltwins/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "azure",
  "mod": "digitaltwins/timeSeriesDatabaseConnection",
  "fqn": "pulumi_azure.digitaltwins",
  "classes": {
   "azure:digitaltwins/timeSeriesDatabaseConnection:TimeSeriesDatabaseConnection": "TimeSeriesDatabaseConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/aRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/aRecord:ARecord": "ARecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/aaaaRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/aaaaRecord:AaaaRecord": "AaaaRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/cNameRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/cNameRecord:CNameRecord": "CNameRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/caaRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/caaRecord:CaaRecord": "CaaRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/mxRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/mxRecord:MxRecord": "MxRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/nsRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/nsRecord:NsRecord": "NsRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/ptrRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/ptrRecord:PtrRecord": "PtrRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/srvRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/srvRecord:SrvRecord": "SrvRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/txtRecord",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/txtRecord:TxtRecord": "TxtRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "dns/zone",
  "fqn": "pulumi_azure.dns",
  "classes": {
   "azure:dns/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "azure",
  "mod": "domainservices/replicaSet",
  "fqn": "pulumi_azure.domainservices",
  "classes": {
   "azure:domainservices/replicaSet:ReplicaSet": "ReplicaSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "domainservices/service",
  "fqn": "pulumi_azure.domainservices",
  "classes": {
   "azure:domainservices/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "domainservices/serviceTrust",
  "fqn": "pulumi_azure.domainservices",
  "classes": {
   "azure:domainservices/serviceTrust:ServiceTrust": "ServiceTrust"
  }
 },
 {
  "pkg": "azure",
  "mod": "dynatrace/monitor",
  "fqn": "pulumi_azure.dynatrace",
  "classes": {
   "azure:dynatrace/monitor:Monitor": "Monitor"
  }
 },
 {
  "pkg": "azure",
  "mod": "dynatrace/tagRules",
  "fqn": "pulumi_azure.dynatrace",
  "classes": {
   "azure:dynatrace/tagRules:TagRules": "TagRules"
  }
 },
 {
  "pkg": "azure",
  "mod": "elasticcloud/elasticsearch",
  "fqn": "pulumi_azure.elasticcloud",
  "classes": {
   "azure:elasticcloud/elasticsearch:Elasticsearch": "Elasticsearch"
  }
 },
 {
  "pkg": "azure",
  "mod": "elasticsan/elasticSan",
  "fqn": "pulumi_azure.elasticsan",
  "classes": {
   "azure:elasticsan/elasticSan:ElasticSan": "ElasticSan"
  }
 },
 {
  "pkg": "azure",
  "mod": "elasticsan/volume",
  "fqn": "pulumi_azure.elasticsan",
  "classes": {
   "azure:elasticsan/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "azure",
  "mod": "elasticsan/volumeGroup",
  "fqn": "pulumi_azure.elasticsan",
  "classes": {
   "azure:elasticsan/volumeGroup:VolumeGroup": "VolumeGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/domain",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/domainTopic",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/domainTopic:DomainTopic": "DomainTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/eventSubscription",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/eventSubscription:EventSubscription": "EventSubscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/namespace",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/systemTopic",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/systemTopic:SystemTopic": "SystemTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/systemTopicEventSubscription",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/systemTopicEventSubscription:SystemTopicEventSubscription": "SystemTopicEventSubscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventgrid/topic",
  "fqn": "pulumi_azure.eventgrid",
  "classes": {
   "azure:eventgrid/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/authorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/authorizationRule:AuthorizationRule": "AuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/cluster",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/consumerGroup",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/consumerGroup:ConsumerGroup": "ConsumerGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/domain",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventGridTopic",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventGridTopic:EventGridTopic": "EventGridTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventHub",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventHub:EventHub": "EventHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventHubAuthorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventHubAuthorizationRule:EventHubAuthorizationRule": "EventHubAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventHubConsumerGroup",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventHubConsumerGroup:EventHubConsumerGroup": "EventHubConsumerGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventHubNamespace",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventHubNamespace:EventHubNamespace": "EventHubNamespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventHubNamespaceAuthorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventHubNamespaceAuthorizationRule:EventHubNamespaceAuthorizationRule": "EventHubNamespaceAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventSubscription",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventSubscription:EventSubscription": "EventSubscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/eventhubNamespaceDisasterRecoveryConfig",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/eventhubNamespaceDisasterRecoveryConfig:EventhubNamespaceDisasterRecoveryConfig": "EventhubNamespaceDisasterRecoveryConfig"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/namespace",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/namespaceAuthorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/namespaceAuthorizationRule:NamespaceAuthorizationRule": "NamespaceAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/namespaceCustomerManagedKey",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/namespaceCustomerManagedKey:NamespaceCustomerManagedKey": "NamespaceCustomerManagedKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/namespaceSchemaGroup",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/namespaceSchemaGroup:NamespaceSchemaGroup": "NamespaceSchemaGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/queue",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/queueAuthorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/queueAuthorizationRule:QueueAuthorizationRule": "QueueAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/subscription",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/subscriptionRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/subscriptionRule:SubscriptionRule": "SubscriptionRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/topic",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "azure",
  "mod": "eventhub/topicAuthorizationRule",
  "fqn": "pulumi_azure.eventhub",
  "classes": {
   "azure:eventhub/topicAuthorizationRule:TopicAuthorizationRule": "TopicAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "extendedlocation/customLocation",
  "fqn": "pulumi_azure.extendedlocation",
  "classes": {
   "azure:extendedlocation/customLocation:CustomLocation": "CustomLocation"
  }
 },
 {
  "pkg": "azure",
  "mod": "fabric/capacity",
  "fqn": "pulumi_azure.fabric",
  "classes": {
   "azure:fabric/capacity:Capacity": "Capacity"
  }
 },
 {
  "pkg": "azure",
  "mod": "fluidrelay/server",
  "fqn": "pulumi_azure.fluidrelay",
  "classes": {
   "azure:fluidrelay/server:Server": "Server"
  }
 },
 {
  "pkg": "azure",
  "mod": "frontdoor/customHttpsConfiguration",
  "fqn": "pulumi_azure.frontdoor",
  "classes": {
   "azure:frontdoor/customHttpsConfiguration:CustomHttpsConfiguration": "CustomHttpsConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "frontdoor/firewallPolicy",
  "fqn": "pulumi_azure.frontdoor",
  "classes": {
   "azure:frontdoor/firewallPolicy:FirewallPolicy": "FirewallPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "frontdoor/frontdoor",
  "fqn": "pulumi_azure.frontdoor",
  "classes": {
   "azure:frontdoor/frontdoor:Frontdoor": "Frontdoor"
  }
 },
 {
  "pkg": "azure",
  "mod": "frontdoor/rulesEngine",
  "fqn": "pulumi_azure.frontdoor",
  "classes": {
   "azure:frontdoor/rulesEngine:RulesEngine": "RulesEngine"
  }
 },
 {
  "pkg": "azure",
  "mod": "graph/servicesAccount",
  "fqn": "pulumi_azure.graph",
  "classes": {
   "azure:graph/servicesAccount:ServicesAccount": "ServicesAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/hBaseCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/hBaseCluster:HBaseCluster": "HBaseCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/hadoopCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/hadoopCluster:HadoopCluster": "HadoopCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/interactiveQueryCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/interactiveQueryCluster:InteractiveQueryCluster": "InteractiveQueryCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/kafkaCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/kafkaCluster:KafkaCluster": "KafkaCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "hdinsight/sparkCluster",
  "fqn": "pulumi_azure.hdinsight",
  "classes": {
   "azure:hdinsight/sparkCluster:SparkCluster": "SparkCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "healthcare/dicomService",
  "fqn": "pulumi_azure.healthcare",
  "classes": {
   "azure:healthcare/dicomService:DicomService": "DicomService"
  }
 },
 {
  "pkg": "azure",
  "mod": "healthcare/fhirService",
  "fqn": "pulumi_azure.healthcare",
  "classes": {
   "azure:healthcare/fhirService:FhirService": "FhirService"
  }
 },
 {
  "pkg": "azure",
  "mod": "healthcare/medtechService",
  "fqn": "pulumi_azure.healthcare",
  "classes": {
   "azure:healthcare/medtechService:MedtechService": "MedtechService"
  }
 },
 {
  "pkg": "azure",
  "mod": "healthcare/medtechServiceFhirDestination",
  "fqn": "pulumi_azure.healthcare",
  "classes": {
   "azure:healthcare/medtechServiceFhirDestination:MedtechServiceFhirDestination": "MedtechServiceFhirDestination"
  }
 },
 {
  "pkg": "azure",
  "mod": "healthcare/service",
  "fqn": "pulumi_azure.healthcare",
  "classes": {
   "azure:healthcare/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "healthcare/workspace",
  "fqn": "pulumi_azure.healthcare",
  "classes": {
   "azure:healthcare/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "hpc/cache",
  "fqn": "pulumi_azure.hpc",
  "classes": {
   "azure:hpc/cache:Cache": "Cache"
  }
 },
 {
  "pkg": "azure",
  "mod": "hpc/cacheAccessPolicy",
  "fqn": "pulumi_azure.hpc",
  "classes": {
   "azure:hpc/cacheAccessPolicy:CacheAccessPolicy": "CacheAccessPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "hpc/cacheBlobNfsTarget",
  "fqn": "pulumi_azure.hpc",
  "classes": {
   "azure:hpc/cacheBlobNfsTarget:CacheBlobNfsTarget": "CacheBlobNfsTarget"
  }
 },
 {
  "pkg": "azure",
  "mod": "hpc/cacheBlobTarget",
  "fqn": "pulumi_azure.hpc",
  "classes": {
   "azure:hpc/cacheBlobTarget:CacheBlobTarget": "CacheBlobTarget"
  }
 },
 {
  "pkg": "azure",
  "mod": "hpc/cacheNfsTarget",
  "fqn": "pulumi_azure.hpc",
  "classes": {
   "azure:hpc/cacheNfsTarget:CacheNfsTarget": "CacheNfsTarget"
  }
 },
 {
  "pkg": "azure",
  "mod": "hsm/module",
  "fqn": "pulumi_azure.hsm",
  "classes": {
   "azure:hsm/module:Module": "Module"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/certificate",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/consumerGroup",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/consumerGroup:ConsumerGroup": "ConsumerGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/dpsSharedAccessPolicy",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/dpsSharedAccessPolicy:DpsSharedAccessPolicy": "DpsSharedAccessPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/endpointCosmosdbAccount",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/endpointCosmosdbAccount:EndpointCosmosdbAccount": "EndpointCosmosdbAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/endpointEventhub",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/endpointEventhub:EndpointEventhub": "EndpointEventhub"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/endpointServicebusQueue",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/endpointServicebusQueue:EndpointServicebusQueue": "EndpointServicebusQueue"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/endpointServicebusTopic",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/endpointServicebusTopic:EndpointServicebusTopic": "EndpointServicebusTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/endpointStorageContainer",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/endpointStorageContainer:EndpointStorageContainer": "EndpointStorageContainer"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/enrichment",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/enrichment:Enrichment": "Enrichment"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/fallbackRoute",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/fallbackRoute:FallbackRoute": "FallbackRoute"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/fileUpload",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/fileUpload:FileUpload": "FileUpload"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/ioTHub",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/ioTHub:IoTHub": "IoTHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/iotHubCertificate",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/iotHubCertificate:IotHubCertificate": "IotHubCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/iotHubDeviceUpdateAccount",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/iotHubDeviceUpdateAccount:IotHubDeviceUpdateAccount": "IotHubDeviceUpdateAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/iotHubDeviceUpdateInstance",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/iotHubDeviceUpdateInstance:IotHubDeviceUpdateInstance": "IotHubDeviceUpdateInstance"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/iotHubDps",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/iotHubDps:IotHubDps": "IotHubDps"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/route",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/route:Route": "Route"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/securityDeviceGroup",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/securityDeviceGroup:SecurityDeviceGroup": "SecurityDeviceGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/securitySolution",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/securitySolution:SecuritySolution": "SecuritySolution"
  }
 },
 {
  "pkg": "azure",
  "mod": "iot/sharedAccessPolicy",
  "fqn": "pulumi_azure.iot",
  "classes": {
   "azure:iot/sharedAccessPolicy:SharedAccessPolicy": "SharedAccessPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "iotcentral/application",
  "fqn": "pulumi_azure.iotcentral",
  "classes": {
   "azure:iotcentral/application:Application": "Application"
  }
 },
 {
  "pkg": "azure",
  "mod": "iotcentral/applicationNetworkRuleSet",
  "fqn": "pulumi_azure.iotcentral",
  "classes": {
   "azure:iotcentral/applicationNetworkRuleSet:ApplicationNetworkRuleSet": "ApplicationNetworkRuleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "iotcentral/organization",
  "fqn": "pulumi_azure.iotcentral",
  "classes": {
   "azure:iotcentral/organization:Organization": "Organization"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/accessPolicy",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/accessPolicy:AccessPolicy": "AccessPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/certifiate",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/certifiate:Certifiate": "Certifiate"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/certificate",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/certificateContacts",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/certificateContacts:CertificateContacts": "CertificateContacts"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/certificateIssuer",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/certificateIssuer:CertificateIssuer": "CertificateIssuer"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/key",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/key:Key": "Key"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/keyVault",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/keyVault:KeyVault": "KeyVault"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/managedHardwareSecurityModule",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/managedHardwareSecurityModule:ManagedHardwareSecurityModule": "ManagedHardwareSecurityModule"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/managedHardwareSecurityModuleKey",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/managedHardwareSecurityModuleKey:ManagedHardwareSecurityModuleKey": "ManagedHardwareSecurityModuleKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/managedHardwareSecurityModuleKeyRotationPolicy",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/managedHardwareSecurityModuleKeyRotationPolicy:ManagedHardwareSecurityModuleKeyRotationPolicy": "ManagedHardwareSecurityModuleKeyRotationPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/managedHardwareSecurityModuleRoleAssignment",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/managedHardwareSecurityModuleRoleAssignment:ManagedHardwareSecurityModuleRoleAssignment": "ManagedHardwareSecurityModuleRoleAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/managedHardwareSecurityModuleRoleDefinition",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/managedHardwareSecurityModuleRoleDefinition:ManagedHardwareSecurityModuleRoleDefinition": "ManagedHardwareSecurityModuleRoleDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/managedStorageAccount",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/managedStorageAccount:ManagedStorageAccount": "ManagedStorageAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/managedStorageAccountSasTokenDefinition",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/managedStorageAccountSasTokenDefinition:ManagedStorageAccountSasTokenDefinition": "ManagedStorageAccountSasTokenDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "keyvault/secret",
  "fqn": "pulumi_azure.keyvault",
  "classes": {
   "azure:keyvault/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/attachedDatabaseConfiguration",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/attachedDatabaseConfiguration:AttachedDatabaseConfiguration": "AttachedDatabaseConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/cluster",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/clusterCustomerManagedKey",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/clusterCustomerManagedKey:ClusterCustomerManagedKey": "ClusterCustomerManagedKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/clusterManagedPrivateEndpoint",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/clusterManagedPrivateEndpoint:ClusterManagedPrivateEndpoint": "ClusterManagedPrivateEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/clusterPrincipalAssignment",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/clusterPrincipalAssignment:ClusterPrincipalAssignment": "ClusterPrincipalAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/cosmosdbDataConnection",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/cosmosdbDataConnection:CosmosdbDataConnection": "CosmosdbDataConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/database",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/database:Database": "Database"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/databasePrincipalAssignment",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/databasePrincipalAssignment:DatabasePrincipalAssignment": "DatabasePrincipalAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/eventGridDataConnection",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/eventGridDataConnection:EventGridDataConnection": "EventGridDataConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/eventhubDataConnection",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/eventhubDataConnection:EventhubDataConnection": "EventhubDataConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/iotHubDataConnection",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/iotHubDataConnection:IotHubDataConnection": "IotHubDataConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "kusto/script",
  "fqn": "pulumi_azure.kusto",
  "classes": {
   "azure:kusto/script:Script": "Script"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/backendAddressPool",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/backendAddressPool:BackendAddressPool": "BackendAddressPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/backendAddressPoolAddress",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/backendAddressPoolAddress:BackendAddressPoolAddress": "BackendAddressPoolAddress"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/loadBalancer",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/natPool",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/natPool:NatPool": "NatPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/natRule",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/natRule:NatRule": "NatRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/outboundRule",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/outboundRule:OutboundRule": "OutboundRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/probe",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/probe:Probe": "Probe"
  }
 },
 {
  "pkg": "azure",
  "mod": "lb/rule",
  "fqn": "pulumi_azure.lb",
  "classes": {
   "azure:lb/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "azure",
  "mod": "lighthouse/assignment",
  "fqn": "pulumi_azure.lighthouse",
  "classes": {
   "azure:lighthouse/assignment:Assignment": "Assignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "lighthouse/definition",
  "fqn": "pulumi_azure.lighthouse",
  "classes": {
   "azure:lighthouse/definition:Definition": "Definition"
  }
 },
 {
  "pkg": "azure",
  "mod": "loadtest/loadTest",
  "fqn": "pulumi_azure.loadtest",
  "classes": {
   "azure:loadtest/loadTest:LoadTest": "LoadTest"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/cluster",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/clusterCustomerManagedKey",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/clusterCustomerManagedKey:ClusterCustomerManagedKey": "ClusterCustomerManagedKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/dataExportRule",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/dataExportRule:DataExportRule": "DataExportRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/dataSourceWindowsEvent",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/dataSourceWindowsEvent:DataSourceWindowsEvent": "DataSourceWindowsEvent"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/dataSourceWindowsPerformanceCounter",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/dataSourceWindowsPerformanceCounter:DataSourceWindowsPerformanceCounter": "DataSourceWindowsPerformanceCounter"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/linkedService",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/linkedService:LinkedService": "LinkedService"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/linkedStorageAccount",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/linkedStorageAccount:LinkedStorageAccount": "LinkedStorageAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/queryPack",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/queryPack:QueryPack": "QueryPack"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/savedSearch",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/savedSearch:SavedSearch": "SavedSearch"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/storageInsights",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/storageInsights:StorageInsights": "StorageInsights"
  }
 },
 {
  "pkg": "azure",
  "mod": "loganalytics/workspaceTable",
  "fqn": "pulumi_azure.loganalytics",
  "classes": {
   "azure:loganalytics/workspaceTable:WorkspaceTable": "WorkspaceTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/actionCustom",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/actionCustom:ActionCustom": "ActionCustom"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/actionHttp",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/actionHttp:ActionHttp": "ActionHttp"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/integrationAccount",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/integrationAccount:IntegrationAccount": "IntegrationAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/integrationAccountAgreement",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/integrationAccountAgreement:IntegrationAccountAgreement": "IntegrationAccountAgreement"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/integrationAccountAssembly",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/integrationAccountAssembly:IntegrationAccountAssembly": "IntegrationAccountAssembly"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/integrationAccountBatchConfiguration",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/integrationAccountBatchConfiguration:IntegrationAccountBatchConfiguration": "IntegrationAccountBatchConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/integrationAccountCertificate",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/integrationAccountCertificate:IntegrationAccountCertificate": "IntegrationAccountCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/integrationAccountMap",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/integrationAccountMap:IntegrationAccountMap": "IntegrationAccountMap"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/integrationAccountPartner",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/integrationAccountPartner:IntegrationAccountPartner": "IntegrationAccountPartner"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/integrationAccountSchema",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/integrationAccountSchema:IntegrationAccountSchema": "IntegrationAccountSchema"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/integrationAccountSession",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/integrationAccountSession:IntegrationAccountSession": "IntegrationAccountSession"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/standard",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/standard:Standard": "Standard"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/triggerCustom",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/triggerCustom:TriggerCustom": "TriggerCustom"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/triggerHttpRequest",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/triggerHttpRequest:TriggerHttpRequest": "TriggerHttpRequest"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/triggerRecurrence",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/triggerRecurrence:TriggerRecurrence": "TriggerRecurrence"
  }
 },
 {
  "pkg": "azure",
  "mod": "logicapps/workflow",
  "fqn": "pulumi_azure.logicapps",
  "classes": {
   "azure:logicapps/workflow:Workflow": "Workflow"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/computeCluster",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/computeCluster:ComputeCluster": "ComputeCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/computeInstance",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/computeInstance:ComputeInstance": "ComputeInstance"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/datastoreBlobstorage",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/datastoreBlobstorage:DatastoreBlobstorage": "DatastoreBlobstorage"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/datastoreDatalakeGen2",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/datastoreDatalakeGen2:DatastoreDatalakeGen2": "DatastoreDatalakeGen2"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/datastoreFileshare",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/datastoreFileshare:DatastoreFileshare": "DatastoreFileshare"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/inferenceCluster",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/inferenceCluster:InferenceCluster": "InferenceCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/synapseSpark",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/synapseSpark:SynapseSpark": "SynapseSpark"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/workspace",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/workspaceNetworkOutboundRuleFqdn",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/workspaceNetworkOutboundRuleFqdn:WorkspaceNetworkOutboundRuleFqdn": "WorkspaceNetworkOutboundRuleFqdn"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/workspaceNetworkOutboundRulePrivateEndpoint",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/workspaceNetworkOutboundRulePrivateEndpoint:WorkspaceNetworkOutboundRulePrivateEndpoint": "WorkspaceNetworkOutboundRulePrivateEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "machinelearning/workspaceNetworkOutboundRuleServiceTag",
  "fqn": "pulumi_azure.machinelearning",
  "classes": {
   "azure:machinelearning/workspaceNetworkOutboundRuleServiceTag:WorkspaceNetworkOutboundRuleServiceTag": "WorkspaceNetworkOutboundRuleServiceTag"
  }
 },
 {
  "pkg": "azure",
  "mod": "maintenance/assignmentDedicatedHost",
  "fqn": "pulumi_azure.maintenance",
  "classes": {
   "azure:maintenance/assignmentDedicatedHost:AssignmentDedicatedHost": "AssignmentDedicatedHost"
  }
 },
 {
  "pkg": "azure",
  "mod": "maintenance/assignmentDynamicScope",
  "fqn": "pulumi_azure.maintenance",
  "classes": {
   "azure:maintenance/assignmentDynamicScope:AssignmentDynamicScope": "AssignmentDynamicScope"
  }
 },
 {
  "pkg": "azure",
  "mod": "maintenance/assignmentVirtualMachine",
  "fqn": "pulumi_azure.maintenance",
  "classes": {
   "azure:maintenance/assignmentVirtualMachine:AssignmentVirtualMachine": "AssignmentVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "maintenance/assignmentVirtualMachineScaleSet",
  "fqn": "pulumi_azure.maintenance",
  "classes": {
   "azure:maintenance/assignmentVirtualMachineScaleSet:AssignmentVirtualMachineScaleSet": "AssignmentVirtualMachineScaleSet"
  }
 },
 {
  "pkg": "azure",
  "mod": "maintenance/configuration",
  "fqn": "pulumi_azure.maintenance",
  "classes": {
   "azure:maintenance/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "azure",
  "mod": "managedapplication/application",
  "fqn": "pulumi_azure.managedapplication",
  "classes": {
   "azure:managedapplication/application:Application": "Application"
  }
 },
 {
  "pkg": "azure",
  "mod": "managedapplication/definition",
  "fqn": "pulumi_azure.managedapplication",
  "classes": {
   "azure:managedapplication/definition:Definition": "Definition"
  }
 },
 {
  "pkg": "azure",
  "mod": "managedlustre/fileSystem",
  "fqn": "pulumi_azure.managedlustre",
  "classes": {
   "azure:managedlustre/fileSystem:FileSystem": "FileSystem"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/group",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/group:Group": "Group"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/groupPolicyAssignment",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/groupPolicyAssignment:GroupPolicyAssignment": "GroupPolicyAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/groupPolicyExemption",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/groupPolicyExemption:GroupPolicyExemption": "GroupPolicyExemption"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/groupPolicyRemediation",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/groupPolicyRemediation:GroupPolicyRemediation": "GroupPolicyRemediation"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/groupSubscriptionAssociation",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/groupSubscriptionAssociation:GroupSubscriptionAssociation": "GroupSubscriptionAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/groupTemplateDeployment",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/groupTemplateDeployment:GroupTemplateDeployment": "GroupTemplateDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/lock",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/lock:Lock": "Lock"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/privateLink",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/privateLink:PrivateLink": "PrivateLink"
  }
 },
 {
  "pkg": "azure",
  "mod": "management/privateLinkAssociation",
  "fqn": "pulumi_azure.management",
  "classes": {
   "azure:management/privateLinkAssociation:PrivateLinkAssociation": "PrivateLinkAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "managementgroups/managementGroup",
  "fqn": "pulumi_azure.managementgroups",
  "classes": {
   "azure:managementgroups/managementGroup:ManagementGroup": "ManagementGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "managementresource/manangementLock",
  "fqn": "pulumi_azure.managementresource",
  "classes": {
   "azure:managementresource/manangementLock:ManangementLock": "ManangementLock"
  }
 },
 {
  "pkg": "azure",
  "mod": "maps/account",
  "fqn": "pulumi_azure.maps",
  "classes": {
   "azure:maps/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "maps/creator",
  "fqn": "pulumi_azure.maps",
  "classes": {
   "azure:maps/creator:Creator": "Creator"
  }
 },
 {
  "pkg": "azure",
  "mod": "marketplace/agreement",
  "fqn": "pulumi_azure.marketplace",
  "classes": {
   "azure:marketplace/agreement:Agreement": "Agreement"
  }
 },
 {
  "pkg": "azure",
  "mod": "marketplace/roleAssignment",
  "fqn": "pulumi_azure.marketplace",
  "classes": {
   "azure:marketplace/roleAssignment:RoleAssignment": "RoleAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "mixedreality/spatialAnchorsAccount",
  "fqn": "pulumi_azure.mixedreality",
  "classes": {
   "azure:mixedreality/spatialAnchorsAccount:SpatialAnchorsAccount": "SpatialAnchorsAccount"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/network",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/network:Network": "Network"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/networkAttachedDataNetwork",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/networkAttachedDataNetwork:NetworkAttachedDataNetwork": "NetworkAttachedDataNetwork"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/networkDataNetwork",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/networkDataNetwork:NetworkDataNetwork": "NetworkDataNetwork"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/networkPacketCoreControlPlane",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/networkPacketCoreControlPlane:NetworkPacketCoreControlPlane": "NetworkPacketCoreControlPlane"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/networkPacketCoreDataPlane",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/networkPacketCoreDataPlane:NetworkPacketCoreDataPlane": "NetworkPacketCoreDataPlane"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/networkService",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/networkService:NetworkService": "NetworkService"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/networkSim",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/networkSim:NetworkSim": "NetworkSim"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/networkSimGroup",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/networkSimGroup:NetworkSimGroup": "NetworkSimGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/networkSimPolicy",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/networkSimPolicy:NetworkSimPolicy": "NetworkSimPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/networkSite",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/networkSite:NetworkSite": "NetworkSite"
  }
 },
 {
  "pkg": "azure",
  "mod": "mobile/networkSlice",
  "fqn": "pulumi_azure.mobile",
  "classes": {
   "azure:mobile/networkSlice:NetworkSlice": "NetworkSlice"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/aadDiagnosticSetting",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/aadDiagnosticSetting:AadDiagnosticSetting": "AadDiagnosticSetting"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/actionGroup",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/actionGroup:ActionGroup": "ActionGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/activityLogAlert",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/activityLogAlert:ActivityLogAlert": "ActivityLogAlert"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/alertProcessingRuleActionGroup",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/alertProcessingRuleActionGroup:AlertProcessingRuleActionGroup": "AlertProcessingRuleActionGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/alertProcessingRuleSuppression",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/alertProcessingRuleSuppression:AlertProcessingRuleSuppression": "AlertProcessingRuleSuppression"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/alertPrometheusRuleGroup",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/alertPrometheusRuleGroup:AlertPrometheusRuleGroup": "AlertPrometheusRuleGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/autoscaleSetting",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/autoscaleSetting:AutoscaleSetting": "AutoscaleSetting"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/dataCollectionEndpoint",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/dataCollectionEndpoint:DataCollectionEndpoint": "DataCollectionEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/dataCollectionRule",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/dataCollectionRule:DataCollectionRule": "DataCollectionRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/dataCollectionRuleAssociation",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/dataCollectionRuleAssociation:DataCollectionRuleAssociation": "DataCollectionRuleAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/diagnosticSetting",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/diagnosticSetting:DiagnosticSetting": "DiagnosticSetting"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/metricAlert",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/metricAlert:MetricAlert": "MetricAlert"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/privateLinkScope",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/privateLinkScope:PrivateLinkScope": "PrivateLinkScope"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/privateLinkScopedService",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/privateLinkScopedService:PrivateLinkScopedService": "PrivateLinkScopedService"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/scheduledQueryRulesAlert",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/scheduledQueryRulesAlert:ScheduledQueryRulesAlert": "ScheduledQueryRulesAlert"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/scheduledQueryRulesAlertV2",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/scheduledQueryRulesAlertV2:ScheduledQueryRulesAlertV2": "ScheduledQueryRulesAlertV2"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/scheduledQueryRulesLog",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/scheduledQueryRulesLog:ScheduledQueryRulesLog": "ScheduledQueryRulesLog"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/smartDetectorAlertRule",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/smartDetectorAlertRule:SmartDetectorAlertRule": "SmartDetectorAlertRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "monitoring/workspace",
  "fqn": "pulumi_azure.monitoring",
  "classes": {
   "azure:monitoring/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "msi/userAssignedIdentity",
  "fqn": "pulumi_azure.msi",
  "classes": {
   "azure:msi/userAssignedIdentity:UserAssignedIdentity": "UserAssignedIdentity"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/database",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/database:Database": "Database"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/databaseExtendedAuditingPolicy",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/databaseExtendedAuditingPolicy:DatabaseExtendedAuditingPolicy": "DatabaseExtendedAuditingPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/databaseVulnerabilityAssessmentRuleBaseline",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/databaseVulnerabilityAssessmentRuleBaseline:DatabaseVulnerabilityAssessmentRuleBaseline": "DatabaseVulnerabilityAssessmentRuleBaseline"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/elasticPool",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/elasticPool:ElasticPool": "ElasticPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/failoverGroup",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/failoverGroup:FailoverGroup": "FailoverGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/firewallRule",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/job",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/job:Job": "Job"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/jobAgent",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/jobAgent:JobAgent": "JobAgent"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/jobCredential",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/jobCredential:JobCredential": "JobCredential"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/jobSchedule",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/jobSchedule:JobSchedule": "JobSchedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/managedDatabase",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/managedDatabase:ManagedDatabase": "ManagedDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/managedInstance",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/managedInstance:ManagedInstance": "ManagedInstance"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/managedInstanceActiveDirectoryAdministrator",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/managedInstanceActiveDirectoryAdministrator:ManagedInstanceActiveDirectoryAdministrator": "ManagedInstanceActiveDirectoryAdministrator"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/managedInstanceFailoverGroup",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/managedInstanceFailoverGroup:ManagedInstanceFailoverGroup": "ManagedInstanceFailoverGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/managedInstanceSecurityAlertPolicy",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/managedInstanceSecurityAlertPolicy:ManagedInstanceSecurityAlertPolicy": "ManagedInstanceSecurityAlertPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/managedInstanceTransparentDataEncryption",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/managedInstanceTransparentDataEncryption:ManagedInstanceTransparentDataEncryption": "ManagedInstanceTransparentDataEncryption"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/managedInstanceVulnerabilityAssessment",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/managedInstanceVulnerabilityAssessment:ManagedInstanceVulnerabilityAssessment": "ManagedInstanceVulnerabilityAssessment"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/outboundFirewallRule",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/outboundFirewallRule:OutboundFirewallRule": "OutboundFirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/server",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/server:Server": "Server"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/serverDnsAlias",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/serverDnsAlias:ServerDnsAlias": "ServerDnsAlias"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/serverExtendedAuditingPolicy",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/serverExtendedAuditingPolicy:ServerExtendedAuditingPolicy": "ServerExtendedAuditingPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/serverMicrosoftSupportAuditingPolicy",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/serverMicrosoftSupportAuditingPolicy:ServerMicrosoftSupportAuditingPolicy": "ServerMicrosoftSupportAuditingPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/serverSecurityAlertPolicy",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/serverSecurityAlertPolicy:ServerSecurityAlertPolicy": "ServerSecurityAlertPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/serverTransparentDataEncryption",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/serverTransparentDataEncryption:ServerTransparentDataEncryption": "ServerTransparentDataEncryption"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/serverVulnerabilityAssessment",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/serverVulnerabilityAssessment:ServerVulnerabilityAssessment": "ServerVulnerabilityAssessment"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/virtualMachine",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/virtualMachine:VirtualMachine": "VirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/virtualMachineAvailabilityGroupListener",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/virtualMachineAvailabilityGroupListener:VirtualMachineAvailabilityGroupListener": "VirtualMachineAvailabilityGroupListener"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/virtualMachineGroup",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/virtualMachineGroup:VirtualMachineGroup": "VirtualMachineGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "mssql/virtualNetworkRule",
  "fqn": "pulumi_azure.mssql",
  "classes": {
   "azure:mssql/virtualNetworkRule:VirtualNetworkRule": "VirtualNetworkRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/flexibleDatabase",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/flexibleDatabase:FlexibleDatabase": "FlexibleDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/flexibleServer",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/flexibleServer:FlexibleServer": "FlexibleServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/flexibleServerActiveDirectoryAdministratory",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/flexibleServerActiveDirectoryAdministratory:FlexibleServerActiveDirectoryAdministratory": "FlexibleServerActiveDirectoryAdministratory"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/flexibleServerConfiguration",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/flexibleServerConfiguration:FlexibleServerConfiguration": "FlexibleServerConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "mysql/flexibleServerFirewallRule",
  "fqn": "pulumi_azure.mysql",
  "classes": {
   "azure:mysql/flexibleServerFirewallRule:FlexibleServerFirewallRule": "FlexibleServerFirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/account",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/accountEncryption",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/accountEncryption:AccountEncryption": "AccountEncryption"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/backupPolicy",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/backupPolicy:BackupPolicy": "BackupPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/backupVault",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/backupVault:BackupVault": "BackupVault"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/pool",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/pool:Pool": "Pool"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/snapshot",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/snapshotPolicy",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/snapshotPolicy:SnapshotPolicy": "SnapshotPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/volume",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/volumeGroupSapHana",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/volumeGroupSapHana:VolumeGroupSapHana": "VolumeGroupSapHana"
  }
 },
 {
  "pkg": "azure",
  "mod": "netapp/volumeQuotaRule",
  "fqn": "pulumi_azure.netapp",
  "classes": {
   "azure:netapp/volumeQuotaRule:VolumeQuotaRule": "VolumeQuotaRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/applicationGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/applicationGateway:ApplicationGateway": "ApplicationGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/applicationSecurityGroup",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/applicationSecurityGroup:ApplicationSecurityGroup": "ApplicationSecurityGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/bgpConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/bgpConnection:BgpConnection": "BgpConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/ddosProtectionPlan",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/ddosProtectionPlan:DdosProtectionPlan": "DdosProtectionPlan"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRouteCircuit",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRouteCircuit:ExpressRouteCircuit": "ExpressRouteCircuit"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRouteCircuitAuthorization",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRouteCircuitAuthorization:ExpressRouteCircuitAuthorization": "ExpressRouteCircuitAuthorization"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRouteCircuitConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRouteCircuitConnection:ExpressRouteCircuitConnection": "ExpressRouteCircuitConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRouteCircuitPeering",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRouteCircuitPeering:ExpressRouteCircuitPeering": "ExpressRouteCircuitPeering"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRouteConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRouteConnection:ExpressRouteConnection": "ExpressRouteConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRouteGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRouteGateway:ExpressRouteGateway": "ExpressRouteGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRoutePort",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRoutePort:ExpressRoutePort": "ExpressRoutePort"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/expressRoutePortAuthorization",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/expressRoutePortAuthorization:ExpressRoutePortAuthorization": "ExpressRoutePortAuthorization"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewall",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewall:Firewall": "Firewall"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewallApplicationRuleCollection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewallApplicationRuleCollection:FirewallApplicationRuleCollection": "FirewallApplicationRuleCollection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewallNatRuleCollection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewallNatRuleCollection:FirewallNatRuleCollection": "FirewallNatRuleCollection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewallNetworkRuleCollection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewallNetworkRuleCollection:FirewallNetworkRuleCollection": "FirewallNetworkRuleCollection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewallPolicy",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewallPolicy:FirewallPolicy": "FirewallPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/firewallPolicyRuleCollectionGroup",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/firewallPolicyRuleCollectionGroup:FirewallPolicyRuleCollectionGroup": "FirewallPolicyRuleCollectionGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/iPGroup",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/iPGroup:IPGroup": "IPGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/iPGroupCIDR",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/iPGroupCIDR:IPGroupCIDR": "IPGroupCIDR"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/localNetworkGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/localNetworkGateway:LocalNetworkGateway": "LocalNetworkGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/natGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/natGateway:NatGateway": "NatGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/natGatewayPublicIpAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/natGatewayPublicIpAssociation:NatGatewayPublicIpAssociation": "NatGatewayPublicIpAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/natGatewayPublicIpPrefixAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/natGatewayPublicIpPrefixAssociation:NatGatewayPublicIpPrefixAssociation": "NatGatewayPublicIpPrefixAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkConnectionMonitor",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkConnectionMonitor:NetworkConnectionMonitor": "NetworkConnectionMonitor"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterface",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterface:NetworkInterface": "NetworkInterface"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterfaceApplicationGatewayBackendAddressPoolAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterfaceApplicationGatewayBackendAddressPoolAssociation:NetworkInterfaceApplicationGatewayBackendAddressPoolAssociation": "NetworkInterfaceApplicationGatewayBackendAddressPoolAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterfaceApplicationSecurityGroupAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterfaceApplicationSecurityGroupAssociation:NetworkInterfaceApplicationSecurityGroupAssociation": "NetworkInterfaceApplicationSecurityGroupAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterfaceBackendAddressPoolAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterfaceBackendAddressPoolAssociation:NetworkInterfaceBackendAddressPoolAssociation": "NetworkInterfaceBackendAddressPoolAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterfaceNatRuleAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterfaceNatRuleAssociation:NetworkInterfaceNatRuleAssociation": "NetworkInterfaceNatRuleAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkInterfaceSecurityGroupAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkInterfaceSecurityGroupAssociation:NetworkInterfaceSecurityGroupAssociation": "NetworkInterfaceSecurityGroupAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManager",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManager:NetworkManager": "NetworkManager"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManagerAdminRule",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManagerAdminRule:NetworkManagerAdminRule": "NetworkManagerAdminRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManagerAdminRuleCollection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManagerAdminRuleCollection:NetworkManagerAdminRuleCollection": "NetworkManagerAdminRuleCollection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManagerConnectivityConfiguration",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManagerConnectivityConfiguration:NetworkManagerConnectivityConfiguration": "NetworkManagerConnectivityConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManagerDeployment",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManagerDeployment:NetworkManagerDeployment": "NetworkManagerDeployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManagerManagementGroupConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManagerManagementGroupConnection:NetworkManagerManagementGroupConnection": "NetworkManagerManagementGroupConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManagerNetworkGroup",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManagerNetworkGroup:NetworkManagerNetworkGroup": "NetworkManagerNetworkGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManagerScopeConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManagerScopeConnection:NetworkManagerScopeConnection": "NetworkManagerScopeConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManagerSecurityAdminConfiguration",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManagerSecurityAdminConfiguration:NetworkManagerSecurityAdminConfiguration": "NetworkManagerSecurityAdminConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManagerStaticMember",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManagerStaticMember:NetworkManagerStaticMember": "NetworkManagerStaticMember"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkManagerSubscriptionConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkManagerSubscriptionConnection:NetworkManagerSubscriptionConnection": "NetworkManagerSubscriptionConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkSecurityGroup",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkSecurityGroup:NetworkSecurityGroup": "NetworkSecurityGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkSecurityRule",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkSecurityRule:NetworkSecurityRule": "NetworkSecurityRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkWatcher",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkWatcher:NetworkWatcher": "NetworkWatcher"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/networkWatcherFlowLog",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/networkWatcherFlowLog:NetworkWatcherFlowLog": "NetworkWatcherFlowLog"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/pointToPointVpnGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/pointToPointVpnGateway:PointToPointVpnGateway": "PointToPointVpnGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/profile",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/publicIp",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/publicIp:PublicIp": "PublicIp"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/publicIpPrefix",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/publicIpPrefix:PublicIpPrefix": "PublicIpPrefix"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/route",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/route:Route": "Route"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/routeFilter",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/routeFilter:RouteFilter": "RouteFilter"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/routeMap",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/routeMap:RouteMap": "RouteMap"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/routeServer",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/routeServer:RouteServer": "RouteServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/routeServerBgpConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/routeServerBgpConnection:RouteServerBgpConnection": "RouteServerBgpConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/routeTable",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/routeTable:RouteTable": "RouteTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/routingIntent",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/routingIntent:RoutingIntent": "RoutingIntent"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/securityPartnerProvider",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/securityPartnerProvider:SecurityPartnerProvider": "SecurityPartnerProvider"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/subnet",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/subnet:Subnet": "Subnet"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/subnetNatGatewayAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/subnetNatGatewayAssociation:SubnetNatGatewayAssociation": "SubnetNatGatewayAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/subnetNetworkSecurityGroupAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/subnetNetworkSecurityGroupAssociation:SubnetNetworkSecurityGroupAssociation": "SubnetNetworkSecurityGroupAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/subnetRouteTableAssociation",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/subnetRouteTableAssociation:SubnetRouteTableAssociation": "SubnetRouteTableAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/subnetServiceEndpointStoragePolicy",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/subnetServiceEndpointStoragePolicy:SubnetServiceEndpointStoragePolicy": "SubnetServiceEndpointStoragePolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/trafficManagerAzureEndpoint",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/trafficManagerAzureEndpoint:TrafficManagerAzureEndpoint": "TrafficManagerAzureEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/trafficManagerExternalEndpoint",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/trafficManagerExternalEndpoint:TrafficManagerExternalEndpoint": "TrafficManagerExternalEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/trafficManagerNestedEndpoint",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/trafficManagerNestedEndpoint:TrafficManagerNestedEndpoint": "TrafficManagerNestedEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/trafficManagerProfile",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/trafficManagerProfile:TrafficManagerProfile": "TrafficManagerProfile"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualHub",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualHub:VirtualHub": "VirtualHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualHubConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualHubConnection:VirtualHubConnection": "VirtualHubConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualHubIp",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualHubIp:VirtualHubIp": "VirtualHubIp"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualHubRouteTable",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualHubRouteTable:VirtualHubRouteTable": "VirtualHubRouteTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualHubRouteTableRoute",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualHubRouteTableRoute:VirtualHubRouteTableRoute": "VirtualHubRouteTableRoute"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualNetwork",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualNetwork:VirtualNetwork": "VirtualNetwork"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualNetworkDnsServers",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualNetworkDnsServers:VirtualNetworkDnsServers": "VirtualNetworkDnsServers"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualNetworkGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualNetworkGateway:VirtualNetworkGateway": "VirtualNetworkGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualNetworkGatewayConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualNetworkGatewayConnection:VirtualNetworkGatewayConnection": "VirtualNetworkGatewayConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualNetworkGatewayNatRule",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualNetworkGatewayNatRule:VirtualNetworkGatewayNatRule": "VirtualNetworkGatewayNatRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualNetworkPeering",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualNetworkPeering:VirtualNetworkPeering": "VirtualNetworkPeering"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/virtualWan",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/virtualWan:VirtualWan": "VirtualWan"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/vnpGatewayNatRule",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/vnpGatewayNatRule:VnpGatewayNatRule": "VnpGatewayNatRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/vpnGateway",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/vpnGateway:VpnGateway": "VpnGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/vpnGatewayConnection",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/vpnGatewayConnection:VpnGatewayConnection": "VpnGatewayConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/vpnServerConfiguration",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/vpnServerConfiguration:VpnServerConfiguration": "VpnServerConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/vpnServerConfigurationPolicyGroup",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/vpnServerConfigurationPolicyGroup:VpnServerConfigurationPolicyGroup": "VpnServerConfigurationPolicyGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "network/vpnSite",
  "fqn": "pulumi_azure.network",
  "classes": {
   "azure:network/vpnSite:VpnSite": "VpnSite"
  }
 },
 {
  "pkg": "azure",
  "mod": "networkfunction/azureTrafficCollector",
  "fqn": "pulumi_azure.networkfunction",
  "classes": {
   "azure:networkfunction/azureTrafficCollector:AzureTrafficCollector": "AzureTrafficCollector"
  }
 },
 {
  "pkg": "azure",
  "mod": "networkfunction/collectorPolicy",
  "fqn": "pulumi_azure.networkfunction",
  "classes": {
   "azure:networkfunction/collectorPolicy:CollectorPolicy": "CollectorPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "newrelic/monitor",
  "fqn": "pulumi_azure.newrelic",
  "classes": {
   "azure:newrelic/monitor:Monitor": "Monitor"
  }
 },
 {
  "pkg": "azure",
  "mod": "newrelic/tagRule",
  "fqn": "pulumi_azure.newrelic",
  "classes": {
   "azure:newrelic/tagRule:TagRule": "TagRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "nginx/certificate",
  "fqn": "pulumi_azure.nginx",
  "classes": {
   "azure:nginx/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "nginx/configuration",
  "fqn": "pulumi_azure.nginx",
  "classes": {
   "azure:nginx/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "azure",
  "mod": "nginx/deployment",
  "fqn": "pulumi_azure.nginx",
  "classes": {
   "azure:nginx/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "azure",
  "mod": "notificationhub/authorizationRule",
  "fqn": "pulumi_azure.notificationhub",
  "classes": {
   "azure:notificationhub/authorizationRule:AuthorizationRule": "AuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "notificationhub/hub",
  "fqn": "pulumi_azure.notificationhub",
  "classes": {
   "azure:notificationhub/hub:Hub": "Hub"
  }
 },
 {
  "pkg": "azure",
  "mod": "notificationhub/namespace",
  "fqn": "pulumi_azure.notificationhub",
  "classes": {
   "azure:notificationhub/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "operationalinsights/analyticsSolution",
  "fqn": "pulumi_azure.operationalinsights",
  "classes": {
   "azure:operationalinsights/analyticsSolution:AnalyticsSolution": "AnalyticsSolution"
  }
 },
 {
  "pkg": "azure",
  "mod": "operationalinsights/analyticsWorkspace",
  "fqn": "pulumi_azure.operationalinsights",
  "classes": {
   "azure:operationalinsights/analyticsWorkspace:AnalyticsWorkspace": "AnalyticsWorkspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "operationalinsights/queryPackQuery",
  "fqn": "pulumi_azure.operationalinsights",
  "classes": {
   "azure:operationalinsights/queryPackQuery:QueryPackQuery": "QueryPackQuery"
  }
 },
 {
  "pkg": "azure",
  "mod": "oracle/autonomousDatabase",
  "fqn": "pulumi_azure.oracle",
  "classes": {
   "azure:oracle/autonomousDatabase:AutonomousDatabase": "AutonomousDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "oracle/cloudVmCluster",
  "fqn": "pulumi_azure.oracle",
  "classes": {
   "azure:oracle/cloudVmCluster:CloudVmCluster": "CloudVmCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "oracle/exadataInfrastructure",
  "fqn": "pulumi_azure.oracle",
  "classes": {
   "azure:oracle/exadataInfrastructure:ExadataInfrastructure": "ExadataInfrastructure"
  }
 },
 {
  "pkg": "azure",
  "mod": "orbital/contact",
  "fqn": "pulumi_azure.orbital",
  "classes": {
   "azure:orbital/contact:Contact": "Contact"
  }
 },
 {
  "pkg": "azure",
  "mod": "orbital/contactProfile",
  "fqn": "pulumi_azure.orbital",
  "classes": {
   "azure:orbital/contactProfile:ContactProfile": "ContactProfile"
  }
 },
 {
  "pkg": "azure",
  "mod": "orbital/spacecraft",
  "fqn": "pulumi_azure.orbital",
  "classes": {
   "azure:orbital/spacecraft:Spacecraft": "Spacecraft"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/localRulestack",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/localRulestack:LocalRulestack": "LocalRulestack"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/localRulestackCertificate",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/localRulestackCertificate:LocalRulestackCertificate": "LocalRulestackCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/localRulestackFqdnList",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/localRulestackFqdnList:LocalRulestackFqdnList": "LocalRulestackFqdnList"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/localRulestackOutboundTrustCertificateAssociation",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/localRulestackOutboundTrustCertificateAssociation:LocalRulestackOutboundTrustCertificateAssociation": "LocalRulestackOutboundTrustCertificateAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/localRulestackOutboundUntrustCertificateAssociation",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/localRulestackOutboundUntrustCertificateAssociation:LocalRulestackOutboundUntrustCertificateAssociation": "LocalRulestackOutboundUntrustCertificateAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/localRulestackPrefixList",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/localRulestackPrefixList:LocalRulestackPrefixList": "LocalRulestackPrefixList"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/localRulestackRule",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/localRulestackRule:LocalRulestackRule": "LocalRulestackRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/nextGenerationFirewallVirtualHubLocalRulestack",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/nextGenerationFirewallVirtualHubLocalRulestack:NextGenerationFirewallVirtualHubLocalRulestack": "NextGenerationFirewallVirtualHubLocalRulestack"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/nextGenerationFirewallVirtualHubPanorama",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/nextGenerationFirewallVirtualHubPanorama:NextGenerationFirewallVirtualHubPanorama": "NextGenerationFirewallVirtualHubPanorama"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/nextGenerationFirewallVirtualNetworkLocalRulestack",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/nextGenerationFirewallVirtualNetworkLocalRulestack:NextGenerationFirewallVirtualNetworkLocalRulestack": "NextGenerationFirewallVirtualNetworkLocalRulestack"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/nextGenerationFirewallVirtualNetworkPanorama",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/nextGenerationFirewallVirtualNetworkPanorama:NextGenerationFirewallVirtualNetworkPanorama": "NextGenerationFirewallVirtualNetworkPanorama"
  }
 },
 {
  "pkg": "azure",
  "mod": "paloalto/virtualNetworkAppliance",
  "fqn": "pulumi_azure.paloalto",
  "classes": {
   "azure:paloalto/virtualNetworkAppliance:VirtualNetworkAppliance": "VirtualNetworkAppliance"
  }
 },
 {
  "pkg": "azure",
  "mod": "pim/activeRoleAssignment",
  "fqn": "pulumi_azure.pim",
  "classes": {
   "azure:pim/activeRoleAssignment:ActiveRoleAssignment": "ActiveRoleAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "pim/eligibleRoleAssignment",
  "fqn": "pulumi_azure.pim",
  "classes": {
   "azure:pim/eligibleRoleAssignment:EligibleRoleAssignment": "EligibleRoleAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "pim/roleManagementPolicy",
  "fqn": "pulumi_azure.pim",
  "classes": {
   "azure:pim/roleManagementPolicy:RoleManagementPolicy": "RoleManagementPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "policy/definition",
  "fqn": "pulumi_azure.policy",
  "classes": {
   "azure:policy/definition:Definition": "Definition"
  }
 },
 {
  "pkg": "azure",
  "mod": "policy/policySetDefinition",
  "fqn": "pulumi_azure.policy",
  "classes": {
   "azure:policy/policySetDefinition:PolicySetDefinition": "PolicySetDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "policy/virtualMachineConfigurationAssignment",
  "fqn": "pulumi_azure.policy",
  "classes": {
   "azure:policy/virtualMachineConfigurationAssignment:VirtualMachineConfigurationAssignment": "VirtualMachineConfigurationAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "portal/portalDashboard",
  "fqn": "pulumi_azure.portal",
  "classes": {
   "azure:portal/portalDashboard:PortalDashboard": "PortalDashboard"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/activeDirectoryAdministrator",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/activeDirectoryAdministrator:ActiveDirectoryAdministrator": "ActiveDirectoryAdministrator"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/configuration",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/configuration:Configuration": "Configuration"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/database",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/database:Database": "Database"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/firewallRule",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/flexibleServer",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/flexibleServer:FlexibleServer": "FlexibleServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/flexibleServerActiveDirectoryAdministrator",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/flexibleServerActiveDirectoryAdministrator:FlexibleServerActiveDirectoryAdministrator": "FlexibleServerActiveDirectoryAdministrator"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/flexibleServerConfiguration",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/flexibleServerConfiguration:FlexibleServerConfiguration": "FlexibleServerConfiguration"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/flexibleServerDatabase",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/flexibleServerDatabase:FlexibleServerDatabase": "FlexibleServerDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/flexibleServerFirewallRule",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/flexibleServerFirewallRule:FlexibleServerFirewallRule": "FlexibleServerFirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/flexibleServerVirtualEndpoint",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/flexibleServerVirtualEndpoint:FlexibleServerVirtualEndpoint": "FlexibleServerVirtualEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/server",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/server:Server": "Server"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/serverKey",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/serverKey:ServerKey": "ServerKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "postgresql/virtualNetworkRule",
  "fqn": "pulumi_azure.postgresql",
  "classes": {
   "azure:postgresql/virtualNetworkRule:VirtualNetworkRule": "VirtualNetworkRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "powerbi/embedded",
  "fqn": "pulumi_azure.powerbi",
  "classes": {
   "azure:powerbi/embedded:Embedded": "Embedded"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/aAAARecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/aAAARecord:AAAARecord": "AAAARecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/aRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/aRecord:ARecord": "ARecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/cnameRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/cnameRecord:CnameRecord": "CnameRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/linkService",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/linkService:LinkService": "LinkService"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/mxRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/mxRecord:MxRecord": "MxRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/pTRRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/pTRRecord:PTRRecord": "PTRRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/resolver",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/resolver:Resolver": "Resolver"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/resolverDnsForwardingRuleset",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/resolverDnsForwardingRuleset:ResolverDnsForwardingRuleset": "ResolverDnsForwardingRuleset"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/resolverForwardingRule",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/resolverForwardingRule:ResolverForwardingRule": "ResolverForwardingRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/resolverInboundEndpoint",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/resolverInboundEndpoint:ResolverInboundEndpoint": "ResolverInboundEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/resolverOutboundEndpoint",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/resolverOutboundEndpoint:ResolverOutboundEndpoint": "ResolverOutboundEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/resolverVirtualNetworkLink",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/resolverVirtualNetworkLink:ResolverVirtualNetworkLink": "ResolverVirtualNetworkLink"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/sRVRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/sRVRecord:SRVRecord": "SRVRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/txtRecord",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/txtRecord:TxtRecord": "TxtRecord"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/zone",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatedns/zoneVirtualNetworkLink",
  "fqn": "pulumi_azure.privatedns",
  "classes": {
   "azure:privatedns/zoneVirtualNetworkLink:ZoneVirtualNetworkLink": "ZoneVirtualNetworkLink"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatelink/applicationSecurityGroupAssociation",
  "fqn": "pulumi_azure.privatelink",
  "classes": {
   "azure:privatelink/applicationSecurityGroupAssociation:ApplicationSecurityGroupAssociation": "ApplicationSecurityGroupAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "privatelink/endpoint",
  "fqn": "pulumi_azure.privatelink",
  "classes": {
   "azure:privatelink/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "proximity/placementGroup",
  "fqn": "pulumi_azure.proximity",
  "classes": {
   "azure:proximity/placementGroup:PlacementGroup": "PlacementGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "purview/account",
  "fqn": "pulumi_azure.purview",
  "classes": {
   "azure:purview/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "recoveryservices/vault",
  "fqn": "pulumi_azure.recoveryservices",
  "classes": {
   "azure:recoveryservices/vault:Vault": "Vault"
  }
 },
 {
  "pkg": "azure",
  "mod": "recoveryservices/vaultResourceGuardAssociation",
  "fqn": "pulumi_azure.recoveryservices",
  "classes": {
   "azure:recoveryservices/vaultResourceGuardAssociation:VaultResourceGuardAssociation": "VaultResourceGuardAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "redhatopenshift/cluster",
  "fqn": "pulumi_azure.redhatopenshift",
  "classes": {
   "azure:redhatopenshift/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/cache",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/cache:Cache": "Cache"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/cacheAccessPolicy",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/cacheAccessPolicy:CacheAccessPolicy": "CacheAccessPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/cacheAccessPolicyAssignment",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/cacheAccessPolicyAssignment:CacheAccessPolicyAssignment": "CacheAccessPolicyAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/enterpriseCluster",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/enterpriseCluster:EnterpriseCluster": "EnterpriseCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/enterpriseDatabase",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/enterpriseDatabase:EnterpriseDatabase": "EnterpriseDatabase"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/firewallRule",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "redis/linkedServer",
  "fqn": "pulumi_azure.redis",
  "classes": {
   "azure:redis/linkedServer:LinkedServer": "LinkedServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "relay/hybridConnection",
  "fqn": "pulumi_azure.relay",
  "classes": {
   "azure:relay/hybridConnection:HybridConnection": "HybridConnection"
  }
 },
 {
  "pkg": "azure",
  "mod": "relay/hybridConnectionAuthorizationRule",
  "fqn": "pulumi_azure.relay",
  "classes": {
   "azure:relay/hybridConnectionAuthorizationRule:HybridConnectionAuthorizationRule": "HybridConnectionAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "relay/namespace",
  "fqn": "pulumi_azure.relay",
  "classes": {
   "azure:relay/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "relay/namespaceAuthorizationRule",
  "fqn": "pulumi_azure.relay",
  "classes": {
   "azure:relay/namespaceAuthorizationRule:NamespaceAuthorizationRule": "NamespaceAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "role/assignment",
  "fqn": "pulumi_azure.role",
  "classes": {
   "azure:role/assignment:Assignment": "Assignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "role/definition",
  "fqn": "pulumi_azure.role",
  "classes": {
   "azure:role/definition:Definition": "Definition"
  }
 },
 {
  "pkg": "azure",
  "mod": "search/service",
  "fqn": "pulumi_azure.search",
  "classes": {
   "azure:search/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "search/sharedPrivateLinkService",
  "fqn": "pulumi_azure.search",
  "classes": {
   "azure:search/sharedPrivateLinkService:SharedPrivateLinkService": "SharedPrivateLinkService"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/advancedThreatProtection",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/advancedThreatProtection:AdvancedThreatProtection": "AdvancedThreatProtection"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/assessment",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/assessment:Assessment": "Assessment"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/assessmentPolicy",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/assessmentPolicy:AssessmentPolicy": "AssessmentPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/autoProvisioning",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/autoProvisioning:AutoProvisioning": "AutoProvisioning"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/automation",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/automation:Automation": "Automation"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/contact",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/contact:Contact": "Contact"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/serverVulnerabilityAssessmentVirtualMachine",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/serverVulnerabilityAssessmentVirtualMachine:ServerVulnerabilityAssessmentVirtualMachine": "ServerVulnerabilityAssessmentVirtualMachine"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/serverVulnerabilityAssessmentsSetting",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/serverVulnerabilityAssessmentsSetting:ServerVulnerabilityAssessmentsSetting": "ServerVulnerabilityAssessmentsSetting"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/setting",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/setting:Setting": "Setting"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/storageDefender",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/storageDefender:StorageDefender": "StorageDefender"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/subscriptionPricing",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/subscriptionPricing:SubscriptionPricing": "SubscriptionPricing"
  }
 },
 {
  "pkg": "azure",
  "mod": "securitycenter/workspace",
  "fqn": "pulumi_azure.securitycenter",
  "classes": {
   "azure:securitycenter/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleAnomalyBuiltIn",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleAnomalyBuiltIn:AlertRuleAnomalyBuiltIn": "AlertRuleAnomalyBuiltIn"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleAnomalyDuplicate",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleAnomalyDuplicate:AlertRuleAnomalyDuplicate": "AlertRuleAnomalyDuplicate"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleFusion",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleFusion:AlertRuleFusion": "AlertRuleFusion"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleMachineLearningBehaviorAnalytics",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleMachineLearningBehaviorAnalytics:AlertRuleMachineLearningBehaviorAnalytics": "AlertRuleMachineLearningBehaviorAnalytics"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleMsSecurityIncident",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleMsSecurityIncident:AlertRuleMsSecurityIncident": "AlertRuleMsSecurityIncident"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleNrt",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleNrt:AlertRuleNrt": "AlertRuleNrt"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleScheduled",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleScheduled:AlertRuleScheduled": "AlertRuleScheduled"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/alertRuleThreatIntelligence",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/alertRuleThreatIntelligence:AlertRuleThreatIntelligence": "AlertRuleThreatIntelligence"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/authomationRule",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/authomationRule:AuthomationRule": "AuthomationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/automationRule",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/automationRule:AutomationRule": "AutomationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorAwsCloudTrail",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorAwsCloudTrail:DataConnectorAwsCloudTrail": "DataConnectorAwsCloudTrail"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorAwsS3",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorAwsS3:DataConnectorAwsS3": "DataConnectorAwsS3"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorAzureActiveDirectory",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorAzureActiveDirectory:DataConnectorAzureActiveDirectory": "DataConnectorAzureActiveDirectory"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorAzureAdvancedThreadProtection",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorAzureAdvancedThreadProtection:DataConnectorAzureAdvancedThreadProtection": "DataConnectorAzureAdvancedThreadProtection"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorAzureSecurityCenter",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorAzureSecurityCenter:DataConnectorAzureSecurityCenter": "DataConnectorAzureSecurityCenter"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorDynamics365",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorDynamics365:DataConnectorDynamics365": "DataConnectorDynamics365"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorIot",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorIot:DataConnectorIot": "DataConnectorIot"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorMicrosoftCloudAppSecurity",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorMicrosoftCloudAppSecurity:DataConnectorMicrosoftCloudAppSecurity": "DataConnectorMicrosoftCloudAppSecurity"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorMicrosoftDefenderAdvancedThreatProtection",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorMicrosoftDefenderAdvancedThreatProtection:DataConnectorMicrosoftDefenderAdvancedThreatProtection": "DataConnectorMicrosoftDefenderAdvancedThreatProtection"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorMicrosoftThreatIntelligence",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorMicrosoftThreatIntelligence:DataConnectorMicrosoftThreatIntelligence": "DataConnectorMicrosoftThreatIntelligence"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorMicrosoftThreatProtection",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorMicrosoftThreatProtection:DataConnectorMicrosoftThreatProtection": "DataConnectorMicrosoftThreatProtection"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorOffice365",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorOffice365:DataConnectorOffice365": "DataConnectorOffice365"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorOffice365Project",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorOffice365Project:DataConnectorOffice365Project": "DataConnectorOffice365Project"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorOfficeAtp",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorOfficeAtp:DataConnectorOfficeAtp": "DataConnectorOfficeAtp"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorOfficeIrm",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorOfficeIrm:DataConnectorOfficeIrm": "DataConnectorOfficeIrm"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorOfficePowerBi",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorOfficePowerBi:DataConnectorOfficePowerBi": "DataConnectorOfficePowerBi"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorThreatIntelligence",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorThreatIntelligence:DataConnectorThreatIntelligence": "DataConnectorThreatIntelligence"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/dataConnectorThreatIntelligenceTaxii",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/dataConnectorThreatIntelligenceTaxii:DataConnectorThreatIntelligenceTaxii": "DataConnectorThreatIntelligenceTaxii"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/logAnalyticsWorkspaceOnboarding",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/logAnalyticsWorkspaceOnboarding:LogAnalyticsWorkspaceOnboarding": "LogAnalyticsWorkspaceOnboarding"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/metadata",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/metadata:Metadata": "Metadata"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/threatIntelligenceIndicator",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/threatIntelligenceIndicator:ThreatIntelligenceIndicator": "ThreatIntelligenceIndicator"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/watchlist",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/watchlist:Watchlist": "Watchlist"
  }
 },
 {
  "pkg": "azure",
  "mod": "sentinel/watchlistItem",
  "fqn": "pulumi_azure.sentinel",
  "classes": {
   "azure:sentinel/watchlistItem:WatchlistItem": "WatchlistItem"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/namespace",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/namespaceAuthorizationRule",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/namespaceAuthorizationRule:NamespaceAuthorizationRule": "NamespaceAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/namespaceDisasterRecoveryConfig",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/namespaceDisasterRecoveryConfig:NamespaceDisasterRecoveryConfig": "NamespaceDisasterRecoveryConfig"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/queue",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/queueAuthorizationRule",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/queueAuthorizationRule:QueueAuthorizationRule": "QueueAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/subscription",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/subscriptionRule",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/subscriptionRule:SubscriptionRule": "SubscriptionRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/topic",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicebus/topicAuthorizationRule",
  "fqn": "pulumi_azure.servicebus",
  "classes": {
   "azure:servicebus/topicAuthorizationRule:TopicAuthorizationRule": "TopicAuthorizationRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicefabric/cluster",
  "fqn": "pulumi_azure.servicefabric",
  "classes": {
   "azure:servicefabric/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "servicefabric/managedCluster",
  "fqn": "pulumi_azure.servicefabric",
  "classes": {
   "azure:servicefabric/managedCluster:ManagedCluster": "ManagedCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "signalr/service",
  "fqn": "pulumi_azure.signalr",
  "classes": {
   "azure:signalr/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "signalr/serviceCustomCertificate",
  "fqn": "pulumi_azure.signalr",
  "classes": {
   "azure:signalr/serviceCustomCertificate:ServiceCustomCertificate": "ServiceCustomCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "signalr/serviceCustomDomain",
  "fqn": "pulumi_azure.signalr",
  "classes": {
   "azure:signalr/serviceCustomDomain:ServiceCustomDomain": "ServiceCustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "signalr/serviceNetworkAcl",
  "fqn": "pulumi_azure.signalr",
  "classes": {
   "azure:signalr/serviceNetworkAcl:ServiceNetworkAcl": "ServiceNetworkAcl"
  }
 },
 {
  "pkg": "azure",
  "mod": "signalr/sharedPrivateLinkResource",
  "fqn": "pulumi_azure.signalr",
  "classes": {
   "azure:signalr/sharedPrivateLinkResource:SharedPrivateLinkResource": "SharedPrivateLinkResource"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/fabric",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/fabric:Fabric": "Fabric"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/hyperVReplicationPolicy",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/hyperVReplicationPolicy:HyperVReplicationPolicy": "HyperVReplicationPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/hyperVReplicationPolicyAssociation",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/hyperVReplicationPolicyAssociation:HyperVReplicationPolicyAssociation": "HyperVReplicationPolicyAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/hyperVSite",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/hyperVSite:HyperVSite": "HyperVSite"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/hypervNetworkMapping",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/hypervNetworkMapping:HypervNetworkMapping": "HypervNetworkMapping"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/networkMapping",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/networkMapping:NetworkMapping": "NetworkMapping"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/protectionContainer",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/protectionContainer:ProtectionContainer": "ProtectionContainer"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/protectionContainerMapping",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/protectionContainerMapping:ProtectionContainerMapping": "ProtectionContainerMapping"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/replicatedVM",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/replicatedVM:ReplicatedVM": "ReplicatedVM"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/replicationPolicy",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/replicationPolicy:ReplicationPolicy": "ReplicationPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/replicationRecoveryPlan",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/replicationRecoveryPlan:ReplicationRecoveryPlan": "ReplicationRecoveryPlan"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/vMWareReplicationPolicy",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/vMWareReplicationPolicy:VMWareReplicationPolicy": "VMWareReplicationPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/vmwareReplicatedVm",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/vmwareReplicatedVm:VmwareReplicatedVm": "VmwareReplicatedVm"
  }
 },
 {
  "pkg": "azure",
  "mod": "siterecovery/vmwareReplicationPolicyAssociation",
  "fqn": "pulumi_azure.siterecovery",
  "classes": {
   "azure:siterecovery/vmwareReplicationPolicyAssociation:VmwareReplicationPolicyAssociation": "VmwareReplicationPolicyAssociation"
  }
 },
 {
  "pkg": "azure",
  "mod": "stack/hciCluster",
  "fqn": "pulumi_azure.stack",
  "classes": {
   "azure:stack/hciCluster:HciCluster": "HciCluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "stack/hciDeploymentSetting",
  "fqn": "pulumi_azure.stack",
  "classes": {
   "azure:stack/hciDeploymentSetting:HciDeploymentSetting": "HciDeploymentSetting"
  }
 },
 {
  "pkg": "azure",
  "mod": "stack/hciExtension",
  "fqn": "pulumi_azure.stack",
  "classes": {
   "azure:stack/hciExtension:HciExtension": "HciExtension"
  }
 },
 {
  "pkg": "azure",
  "mod": "stack/hciLogicalNetwork",
  "fqn": "pulumi_azure.stack",
  "classes": {
   "azure:stack/hciLogicalNetwork:HciLogicalNetwork": "HciLogicalNetwork"
  }
 },
 {
  "pkg": "azure",
  "mod": "stack/hciMarketplaceGalleryImage",
  "fqn": "pulumi_azure.stack",
  "classes": {
   "azure:stack/hciMarketplaceGalleryImage:HciMarketplaceGalleryImage": "HciMarketplaceGalleryImage"
  }
 },
 {
  "pkg": "azure",
  "mod": "stack/hciNetworkInterface",
  "fqn": "pulumi_azure.stack",
  "classes": {
   "azure:stack/hciNetworkInterface:HciNetworkInterface": "HciNetworkInterface"
  }
 },
 {
  "pkg": "azure",
  "mod": "stack/hciStoragePath",
  "fqn": "pulumi_azure.stack",
  "classes": {
   "azure:stack/hciStoragePath:HciStoragePath": "HciStoragePath"
  }
 },
 {
  "pkg": "azure",
  "mod": "stack/hciVirtualHardDisk",
  "fqn": "pulumi_azure.stack",
  "classes": {
   "azure:stack/hciVirtualHardDisk:HciVirtualHardDisk": "HciVirtualHardDisk"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/account",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/accountNetworkRules",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/accountNetworkRules:AccountNetworkRules": "AccountNetworkRules"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/accountQueueProperties",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/accountQueueProperties:AccountQueueProperties": "AccountQueueProperties"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/accountStaticWebsite",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/accountStaticWebsite:AccountStaticWebsite": "AccountStaticWebsite"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/blob",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/blob:Blob": "Blob"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/blobInventoryPolicy",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/blobInventoryPolicy:BlobInventoryPolicy": "BlobInventoryPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/container",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/container:Container": "Container"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/containerImmutabilityPolicy",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/containerImmutabilityPolicy:ContainerImmutabilityPolicy": "ContainerImmutabilityPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/customerManagedKey",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/customerManagedKey:CustomerManagedKey": "CustomerManagedKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/dataLakeGen2Filesystem",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/dataLakeGen2Filesystem:DataLakeGen2Filesystem": "DataLakeGen2Filesystem"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/dataLakeGen2Path",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/dataLakeGen2Path:DataLakeGen2Path": "DataLakeGen2Path"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/encryptionScope",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/encryptionScope:EncryptionScope": "EncryptionScope"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/localUser",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/localUser:LocalUser": "LocalUser"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/managementPolicy",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/managementPolicy:ManagementPolicy": "ManagementPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/mover",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/mover:Mover": "Mover"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/moverAgent",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/moverAgent:MoverAgent": "MoverAgent"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/moverJobDefinition",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/moverJobDefinition:MoverJobDefinition": "MoverJobDefinition"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/moverProject",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/moverProject:MoverProject": "MoverProject"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/moverSourceEndpoint",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/moverSourceEndpoint:MoverSourceEndpoint": "MoverSourceEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/moverTargetEndpoint",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/moverTargetEndpoint:MoverTargetEndpoint": "MoverTargetEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/objectReplication",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/objectReplication:ObjectReplication": "ObjectReplication"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/queue",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/share",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/share:Share": "Share"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/shareDirectory",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/shareDirectory:ShareDirectory": "ShareDirectory"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/shareFile",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/shareFile:ShareFile": "ShareFile"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/sync",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/sync:Sync": "Sync"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/syncCloudEndpoint",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/syncCloudEndpoint:SyncCloudEndpoint": "SyncCloudEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/syncGroup",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/syncGroup:SyncGroup": "SyncGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/syncServerEndpoint",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/syncServerEndpoint:SyncServerEndpoint": "SyncServerEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/table",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/table:Table": "Table"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/tableEntity",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/tableEntity:TableEntity": "TableEntity"
  }
 },
 {
  "pkg": "azure",
  "mod": "storage/zipBlob",
  "fqn": "pulumi_azure.storage",
  "classes": {
   "azure:storage/zipBlob:ZipBlob": "ZipBlob"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/cluster",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/functionJavaScriptUDF",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/functionJavaScriptUDF:FunctionJavaScriptUDF": "FunctionJavaScriptUDF"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/functionJavascriptUda",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/functionJavascriptUda:FunctionJavascriptUda": "FunctionJavascriptUda"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/job",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/job:Job": "Job"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/jobSchedule",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/jobSchedule:JobSchedule": "JobSchedule"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/managedPrivateEndpoint",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/managedPrivateEndpoint:ManagedPrivateEndpoint": "ManagedPrivateEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputBlob",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputBlob:OutputBlob": "OutputBlob"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputCosmosdb",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputCosmosdb:OutputCosmosdb": "OutputCosmosdb"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputEventHub",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputEventHub:OutputEventHub": "OutputEventHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputFunction",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputFunction:OutputFunction": "OutputFunction"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputMssql",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputMssql:OutputMssql": "OutputMssql"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputPowerbi",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputPowerbi:OutputPowerbi": "OutputPowerbi"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputServiceBusQueue",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputServiceBusQueue:OutputServiceBusQueue": "OutputServiceBusQueue"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputServicebusTopic",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputServicebusTopic:OutputServicebusTopic": "OutputServicebusTopic"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputSynapse",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputSynapse:OutputSynapse": "OutputSynapse"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/outputTable",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/outputTable:OutputTable": "OutputTable"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/referenceInputBlob",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/referenceInputBlob:ReferenceInputBlob": "ReferenceInputBlob"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/referenceInputMssql",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/referenceInputMssql:ReferenceInputMssql": "ReferenceInputMssql"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/streamInputBlob",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/streamInputBlob:StreamInputBlob": "StreamInputBlob"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/streamInputEventHub",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/streamInputEventHub:StreamInputEventHub": "StreamInputEventHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/streamInputEventHubV2",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/streamInputEventHubV2:StreamInputEventHubV2": "StreamInputEventHubV2"
  }
 },
 {
  "pkg": "azure",
  "mod": "streamanalytics/streamInputIotHub",
  "fqn": "pulumi_azure.streamanalytics",
  "classes": {
   "azure:streamanalytics/streamInputIotHub:StreamInputIotHub": "StreamInputIotHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/firewallRule",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/integrationRuntimeAzure",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/integrationRuntimeAzure:IntegrationRuntimeAzure": "IntegrationRuntimeAzure"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/integrationRuntimeSelfHosted",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/integrationRuntimeSelfHosted:IntegrationRuntimeSelfHosted": "IntegrationRuntimeSelfHosted"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/linkedService",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/linkedService:LinkedService": "LinkedService"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/managedPrivateEndpoint",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/managedPrivateEndpoint:ManagedPrivateEndpoint": "ManagedPrivateEndpoint"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/privateLinkHub",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/privateLinkHub:PrivateLinkHub": "PrivateLinkHub"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/roleAssignment",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/roleAssignment:RoleAssignment": "RoleAssignment"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/sparkPool",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/sparkPool:SparkPool": "SparkPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/sqlPool",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/sqlPool:SqlPool": "SqlPool"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/sqlPoolExtendedAuditingPolicy",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/sqlPoolExtendedAuditingPolicy:SqlPoolExtendedAuditingPolicy": "SqlPoolExtendedAuditingPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/sqlPoolSecurityAlertPolicy",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/sqlPoolSecurityAlertPolicy:SqlPoolSecurityAlertPolicy": "SqlPoolSecurityAlertPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/sqlPoolVulnerabilityAssessment",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/sqlPoolVulnerabilityAssessment:SqlPoolVulnerabilityAssessment": "SqlPoolVulnerabilityAssessment"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/sqlPoolVulnerabilityAssessmentBaseline",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/sqlPoolVulnerabilityAssessmentBaseline:SqlPoolVulnerabilityAssessmentBaseline": "SqlPoolVulnerabilityAssessmentBaseline"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/sqlPoolWorkloadClassifier",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/sqlPoolWorkloadClassifier:SqlPoolWorkloadClassifier": "SqlPoolWorkloadClassifier"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/sqlPoolWorkloadGroup",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/sqlPoolWorkloadGroup:SqlPoolWorkloadGroup": "SqlPoolWorkloadGroup"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/workspace",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/workspace:Workspace": "Workspace"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/workspaceAadAdmin",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/workspaceAadAdmin:WorkspaceAadAdmin": "WorkspaceAadAdmin"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/workspaceExtendedAuditingPolicy",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/workspaceExtendedAuditingPolicy:WorkspaceExtendedAuditingPolicy": "WorkspaceExtendedAuditingPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/workspaceKey",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/workspaceKey:WorkspaceKey": "WorkspaceKey"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/workspaceSecurityAlertPolicy",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/workspaceSecurityAlertPolicy:WorkspaceSecurityAlertPolicy": "WorkspaceSecurityAlertPolicy"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/workspaceSqlAadAdmin",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/workspaceSqlAadAdmin:WorkspaceSqlAadAdmin": "WorkspaceSqlAadAdmin"
  }
 },
 {
  "pkg": "azure",
  "mod": "synapse/workspaceVulnerabilityAssessment",
  "fqn": "pulumi_azure.synapse",
  "classes": {
   "azure:synapse/workspaceVulnerabilityAssessment:WorkspaceVulnerabilityAssessment": "WorkspaceVulnerabilityAssessment"
  }
 },
 {
  "pkg": "azure",
  "mod": "systemcenter/virtualMachineManagerAvailabilitySet",
  "fqn": "pulumi_azure.systemcenter",
  "classes": {
   "azure:systemcenter/virtualMachineManagerAvailabilitySet:VirtualMachineManagerAvailabilitySet": "VirtualMachineManagerAvailabilitySet"
  }
 },
 {
  "pkg": "azure",
  "mod": "systemcenter/virtualMachineManagerCloud",
  "fqn": "pulumi_azure.systemcenter",
  "classes": {
   "azure:systemcenter/virtualMachineManagerCloud:VirtualMachineManagerCloud": "VirtualMachineManagerCloud"
  }
 },
 {
  "pkg": "azure",
  "mod": "systemcenter/virtualMachineManagerServer",
  "fqn": "pulumi_azure.systemcenter",
  "classes": {
   "azure:systemcenter/virtualMachineManagerServer:VirtualMachineManagerServer": "VirtualMachineManagerServer"
  }
 },
 {
  "pkg": "azure",
  "mod": "systemcenter/virtualMachineManagerVirtualMachineTemplate",
  "fqn": "pulumi_azure.systemcenter",
  "classes": {
   "azure:systemcenter/virtualMachineManagerVirtualMachineTemplate:VirtualMachineManagerVirtualMachineTemplate": "VirtualMachineManagerVirtualMachineTemplate"
  }
 },
 {
  "pkg": "azure",
  "mod": "systemcenter/virtualMachineManagerVirtualNetwork",
  "fqn": "pulumi_azure.systemcenter",
  "classes": {
   "azure:systemcenter/virtualMachineManagerVirtualNetwork:VirtualMachineManagerVirtualNetwork": "VirtualMachineManagerVirtualNetwork"
  }
 },
 {
  "pkg": "azure",
  "mod": "trafficmanager/profile",
  "fqn": "pulumi_azure.trafficmanager",
  "classes": {
   "azure:trafficmanager/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "azure",
  "mod": "trustedsigning/account",
  "fqn": "pulumi_azure.trustedsigning",
  "classes": {
   "azure:trustedsigning/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "videoindexer/account",
  "fqn": "pulumi_azure.videoindexer",
  "classes": {
   "azure:videoindexer/account:Account": "Account"
  }
 },
 {
  "pkg": "azure",
  "mod": "voice/servicesCommunicationsGateway",
  "fqn": "pulumi_azure.voice",
  "classes": {
   "azure:voice/servicesCommunicationsGateway:ServicesCommunicationsGateway": "ServicesCommunicationsGateway"
  }
 },
 {
  "pkg": "azure",
  "mod": "voice/servicesCommunicationsGatewayTestLine",
  "fqn": "pulumi_azure.voice",
  "classes": {
   "azure:voice/servicesCommunicationsGatewayTestLine:ServicesCommunicationsGatewayTestLine": "ServicesCommunicationsGatewayTestLine"
  }
 },
 {
  "pkg": "azure",
  "mod": "waf/policy",
  "fqn": "pulumi_azure.waf",
  "classes": {
   "azure:waf/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "azure",
  "mod": "webpubsub/customCertificate",
  "fqn": "pulumi_azure.webpubsub",
  "classes": {
   "azure:webpubsub/customCertificate:CustomCertificate": "CustomCertificate"
  }
 },
 {
  "pkg": "azure",
  "mod": "webpubsub/customDomain",
  "fqn": "pulumi_azure.webpubsub",
  "classes": {
   "azure:webpubsub/customDomain:CustomDomain": "CustomDomain"
  }
 },
 {
  "pkg": "azure",
  "mod": "webpubsub/hub",
  "fqn": "pulumi_azure.webpubsub",
  "classes": {
   "azure:webpubsub/hub:Hub": "Hub"
  }
 },
 {
  "pkg": "azure",
  "mod": "webpubsub/networkAcl",
  "fqn": "pulumi_azure.webpubsub",
  "classes": {
   "azure:webpubsub/networkAcl:NetworkAcl": "NetworkAcl"
  }
 },
 {
  "pkg": "azure",
  "mod": "webpubsub/service",
  "fqn": "pulumi_azure.webpubsub",
  "classes": {
   "azure:webpubsub/service:Service": "Service"
  }
 },
 {
  "pkg": "azure",
  "mod": "webpubsub/sharedPrivateLinkResource",
  "fqn": "pulumi_azure.webpubsub",
  "classes": {
   "azure:webpubsub/sharedPrivateLinkResource:SharedPrivateLinkResource": "SharedPrivateLinkResource"
  }
 },
 {
  "pkg": "azure",
  "mod": "workloadssap/discoveryVirtualInstance",
  "fqn": "pulumi_azure.workloadssap",
  "classes": {
   "azure:workloadssap/discoveryVirtualInstance:DiscoveryVirtualInstance": "DiscoveryVirtualInstance"
  }
 },
 {
  "pkg": "azure",
  "mod": "workloadssap/singleNodeVirtualInstance",
  "fqn": "pulumi_azure.workloadssap",
  "classes": {
   "azure:workloadssap/singleNodeVirtualInstance:SingleNodeVirtualInstance": "SingleNodeVirtualInstance"
  }
 },
 {
  "pkg": "azure",
  "mod": "workloadssap/threeTierVirtualInstance",
  "fqn": "pulumi_azure.workloadssap",
  "classes": {
   "azure:workloadssap/threeTierVirtualInstance:ThreeTierVirtualInstance": "ThreeTierVirtualInstance"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "azure",
  "token": "pulumi:providers:azure",
  "fqn": "pulumi_azure",
  "class": "Provider"
 }
]
"""
)
